// BitMapLoader.cpp : Defines the entry point for the application.
//

#include "BitMapLoader.h"
#include <iostream>
#include <fstream>    
#include <memory>
using namespace std;

/** BMPLoader Constructor
 **/
BMPLoader::BMPLoader()
    {
    palette = fileData = identifier = bitmapData = NULL;
    fileSize = reserved = bitmapDataOffset = bitmapHeaderSize = 0;
    width = height = planes = bitsPerPixel = compression = 0;
    bitmapDataSize = hResolution = vResolution = colors = importantColors = 0;
    stored = 0;
    }
    
/** BMPLoader Decontstructor
 **/
BMPLoader::~BMPLoader()
    {
    }

/** load - Takes: char* - a filename.
 **        Loads the bitmap into memory.
 **        Returns: int - 0 if no error
 **/
int BMPLoader::load(char* filename)
    {
    int filecheck = 0;;
    filecheck = gatherData(filename);
    filecheck = processHeader();

    // free the space used to hold the file
    delete [] fileData;
    fileData = NULL;
    stored = 1;
    return filecheck;
    }

/** gatherData - Takes: char* - a filename.
 **                 Gets the file size and stores the file in memory
 **                 Returns: int - 0 if no error
 **/
int BMPLoader::gatherData(char* filename)
    {
    fstream fIn;
    //open file for reading in binary mode
    fIn.open(filename,fstream::in | fstream::binary);

      // Get file size
    fIn.seekg(0,ios_base::end);
    fileSize=fIn.tellg();
    fIn.seekg(0,ios_base::beg);

    // make the variable to hold everything the size of the file
    fileData = new unsigned char[fileSize];

    // read everything into the variable
    fIn.read((char*)fileData, fileSize);

    fIn.close();

    return 0;
    }

/** gatherData - Takes: char* - a filename.
 **                 Sifts through the data to place it in its place.
 **                 Returns: int - 0 if no error
 **/
int BMPLoader::processHeader()
    {
    identifier = new unsigned char;
    memcpy(identifier,&fileData[0x0],2);   // identifier

    memcpy(&fileSize,&fileData[0x2],4);   // identifier

    memcpy(&reserved,&fileData[0x6],4);   // reserved

    memcpy(&bitmapDataOffset,&fileData[0xA],4);   // offset of the data from the start of file

    memcpy(&bitmapHeaderSize,&fileData[0xE],4);   // length of the header

    memcpy(&width,&fileData[0x12],4);   // width in pixels

    memcpy(&height,&fileData[0x16],4);   // height in pixels

    memcpy(&planes,&fileData[0x1A],2);   // number of planes

    memcpy(&bitsPerPixel,&fileData[0x1C],2);   // bits per pixel used to store palette
                                                 // 1 = monochrome
                                                 // 4 = 16 color
                                                 // 8 = 256 color bitmap
                                                 // 16 = 16bit (high color) bitmap
                                                 // 24 = 24bit (true color) bitmap
                                                 // 32 = 32bit (true color) bitmap

    memcpy(&compression,&fileData[0x1E],4);   // compression
                                                //  0 - none (Also identified by BI_RGB)
                                                //  1 - RLE 8-bit / pixel (Also identified by BI_RLE4)
                                                //  2 - RLE 4-bit / pixel (Also identified by BI_RLE8)
                                                //  3 - Bitfields  (Also identified by BI_BITFIELDS)

    memcpy(&bitmapDataSize,&fileData[0x22],4);   // size of the bitmap data in bytes

    memcpy(&hResolution,&fileData[0x26],4);   // horizontal resolution in pixels per meter
    
    memcpy(&vResolution,&fileData[0x2A],4);   // vertical resolution in pixels per meter

    memcpy(&colors,&fileData[0x2E],4);   // number of colors 

    memcpy(&importantColors,&fileData[0x32],4);   // important colors
    
    palette = new unsigned char[colors*4];
    for(int i = 0; i<colors; i++){
        memcpy(palette,&fileData[0x36 + 0x4 * i],4);   // define all the colors in the palette
        }

    bitmapData = new unsigned char[bitmapDataSize];
    memcpy(bitmapData,&fileData[bitmapDataOffset],bitmapDataSize);   // size of the data    
    return 0;
    }

int BMPLoader::getSizeX()
    {
    return width;
    }

int BMPLoader::getSizeY()
    {
    return height;
    }

unsigned char* BMPLoader::getBitmapData()
    {
    return bitmapData;
    }

int BMPLoader::isStored()
    {
    return stored;
    }
