// StarSystem.cpp : Defines the entry point for the console application.
//

#include "stdafx.h"
#include <stdlib.h>
#include <stdio.h>
#include <time.h>
#include "StarSystem.h"
#include <string.h>
#include <math.h>
#include "dice.h"

Planet::Planet(){
    planetNumber = -1;
    orbitalRadius = -1.0;
    orbitalSpeed = -1.0;
    rotationalSpeed = -1.0;
    SatelliteType type = Default;
    baseCirc = -1;
    circExponent = -1;
    inStellarEcosphere = -1;
    paramAtmos = -1;
    paramHydro = -1;
    paramClima = -1;
    paramBiosp = -1;
    }

Planet::printPlanet(){
    printf("\n **Planet Info Dump**\n");
    printf("   Planet Number = %d\n", planetNumber);
    printf("   Orbital Radius = %f\n", orbitalRadius);
    switch(type){
        case Rock:
            printf("   Satellite Type = Rock Planet\n");
            break;
        case Gas:
            printf("   Satellite Type = Gas Giant\n");
            break;
        case Asteroid:
            printf("   Satellite Type = Asteroid Field\n");
            break;
        case Empty:
            printf("   Satellite Type = Empty Orbit\n");
            break;
        case Default:
            printf("   Satellite Type = ?\n");
            break;
        }
    printf("   Circumference = %.2f x 10^%d\n", baseCirc, circExponent);
    printf("   Density = %.2f\n", density);
    printf("   Base Gravity = %.2f\n", baseGravity);
    printf("   Escape Velocity = %f KPS\n", baseGravity * 11);
    if( inStellarEcosphere == 1 )
        printf("   This planet is in the stellar ecosphere\n");
    //printf("   Atmosphere Level = %d\n", paramAtmos);
    switch(paramAtmos){
        case 1:
            printf("   Atmosphere is presently escaping the planet\n");
            break;
        case 2:
            printf("   Plethora of toxic trace metals and gases in atmosphere\n");
            break;
        case 3:
            printf("   Exceedingly thin atmosphere\n");
            break;
        case 4:
            printf("   Predominantly chlorine\n");
            break;
        case 5:
            printf("   Mainly ammonia and methane\n");
            break;
        case 6:
            printf("   Predominantly carbon dioxide\n");
            break;
        case 7:
            printf("   Oxygen/Nitrogen/Carbon dioxide and contaminants\n");
            break;
        case 8:
            printf("   Oxygen/Nitrogen with few contaminants\n");
            break;
        case 9:
            printf("   Oxygen/Nitrogen with significant ozone component in stratosphere\n");
            break;
        case 10:
            printf("   A thick atmosphere which is predominantly oxygen and nitrogen\n");
            break;
        case 0:
            printf("   No Atmosphere\n");
            break;
        }
    //printf("   Hydrosphere Level = %d\n", paramHydro);
    switch(paramHydro){
        case 1:
            printf("   No standing water\n");
            break;
        case 2:
            printf("   World is predominantly desert\n");
            break;
        case 3:
            printf("   Arid\n");
            break;
        case 4:
            printf("   Semi-arid\n");
            break;
        case 5:
            printf("   Balanced\n");
            break;
        case 6:
            printf("   Ocean World\n");
            break;
        case 7:
            printf("   Water vapor is major component of atmosphere\n");
            break;
        case 8:
            printf("   Water vapor is major component of atmosphere\n");
            break;
        case 9:
            printf("   Water vapor is major component of atmosphere\n");
            break;
        case 10:
            printf("   Water vapor is major component of atmosphere\n");
            break;
        case 0:
            printf("   No water\n");
            break;
        }
    //printf("   Climate Level = %d\n", paramClima);
    switch(paramClima){
        case 1:
            printf("   This place is an iceball\n");
            break;
        case 2:
            printf("   Arctic climate prevails\n");
            break;
        case 3:
            printf("   A cool temperate mix\n");
            break;
        case 4:
            printf("   Temperate mix\n");
            break;
        case 5:
            printf("   A warm temperate mix\n");
            break;
        case 6:
            printf("   Hot\n");
            break;
        case 7:
            printf("   Greenhouse Inferno\n");
            break;
        case 8:
            printf("   Variable due to an eccentric orbit\n");
            break;
        case 9:
            printf("   Variable due to an unusual rotation period\n");
            break;
        case 10:
            printf("   Hellish\n");
            break;
        case 0:
            printf("   No climate\n");
            break;
        }
    //printf("   Biosphere Level = %d\n", paramBiosp);
    switch(paramBiosp){
        case 1:
            printf("   Biotoxins in atmosphere. They are so exotic as to be normally undetected.\n");
            break;
        case 2:
            printf("   Biotoxins in the atmosphere\n");
            break;
        case 3:
            printf("   No life\n");
            break;
        case 4:
            printf("   No life\n");
            break;
        case 5:
            printf("   No life\n");
            break;
        case 6:
            printf("   Proto-organisms\n");
            break;
        case 7:
            printf("   Proto-organisms and plant-like life\n");
            break;
        case 8:
            printf("   Non-sentient lower life forms\n");
            break;
        case 9:
            printf("   Sentient beings present. Developmental stage should be chosen/generated.\n");
            break;
        case 10:
            printf("   Highly evolved or unusual life form\n");
            break;
        case 0:
            printf("   No life\n");
            break;
        }


    return 0;
    }



StarSystem::StarSystem(){
    key = 0;
    starClass = '?';
    brightness = -1;
    naturalSatellites = -1;
    naturalSatellitesHabitable = -1;
    planetsInEcosphere = 0;
    brightnessVsSol = -1.0;
    radiusVsSol = -1.0;
    massVsSol = -1.0;
    stellarType = -1;
    starDesc = new char;
    strcpy(starDesc, "?");
    planet = new Planet;
    }

int StarSystem::createStar() {
    //Below is order of operation for info in StarSystem

    this->stellarBodyFrequency();
    this->hertzprungRusselDiagram();
    this->stellarMassFind();
    this->gravityWellFind();


    satelliteInfoFind();
    return 0;
    }


int StarSystem::printStar()    {
    printf("\n **Star Info Dump**\n");
    printf("   key = %d\n", key);
    printf("   Star Class = %c\n", starClass);
    printf("   Stellar Type = %d\n", stellarType);
    printf("   Brightness = %d\n", brightness);
    printf("   Brightness Vs Sol = %.6f\n", brightnessVsSol);
    printf("   Radius Vs Sol = %.4f\n", radiusVsSol);
    printf("   Mass Vs Sol = %f\n", massVsSol);
    printf("   Gravity Well = %.3fAU or %.0f million kilometers\n", gravityWell, (gravityWell*150));
    printf("   Star Description: %s\n", starDesc);
    printf("   Natural Sattelites = %d\n", naturalSatellites);
    printf("   Habitable Natural Sattelites = %d\n", naturalSatellitesHabitable);
    printf("   Planets in Stellar Ecosphere = %d\n", planetsInEcosphere);
    for(int i = 0; i < naturalSatellitesHabitable; i++){
        planet[i].printPlanet();
        }
    return 0;
}




/** int randomDie(int die, int numberOfDie){

	int i;
	int total = 0; 
	/* Display numberOfDie numbers. And total up the numbers*/
	/**for( i = 0;   i < numberOfDie;i++ ) {
		int randomNumber = (rand() % die) + 1;
        printf( "  %6d\n", randomNumber );
	    total += randomNumber;
	}
	printf( " Rolled %dD%d total = %d\n", numberOfDie, die, total );
	return total;
}**/
/**
int randomDieOpenEnded(int openLow){
	int i;
    int numberOfDie = 1;
    int die = 100;
	int total = 0;
    if( openLow != 1 ){
        // Open end up only
        /* Display numberOfDie numbers. And total up the numbers*/
	    /**for( i = 0;   i < numberOfDie;i++ ) {
		    int randomNumber = (rand() % die) + 1;
                printf( "  %6d\n", randomNumber );
            while( randomNumber > 95 ){
                total += randomNumber;
                randomNumber = (rand() % die) + 1;
                printf( " *open ended* + %d\n", randomNumber );
                }
            total += randomNumber;
            }
        printf( " Rolled %dD%d OE total = %d\n", numberOfDie, die, total );
        }
    else {
        // Open end up and down
        /* Display numberOfDie numbers. And total up the numbers*/
	 /**   for( i = 0;   i < numberOfDie;i++ ) {
		    int randomNumber = (rand() % die) + 1;
            int direction = 1;
                printf( "  %6d\n", randomNumber );
            while( randomNumber > 95 || randomNumber < 6){
                total += randomNumber * direction;
                if( randomNumber > 95 ){
                    randomNumber = (rand() % die) + 1;
                    printf( " *open ended* + %d\n", randomNumber );
                    }
                else{
                    direction *= -1;
                    randomNumber = (rand() % die) + 1;
                    printf( " *open ended down* - %d\n", randomNumber );
                    }
                }
            total += randomNumber * direction;
            }
        printf( " Rolled %dD%d OEUD total = %d\n", numberOfDie, die, total );
        }

	return total;
    }
**/


int StarSystem::satelliteAtmosphereFind(){
    int random = randomDie(100, 1);
    int inEco = 0;
    switch(this->starClass){
        case 'F':
            if( random <= 30){
                inEco = 0;
                }
            else if( random <= 95 ){
                inEco = 1;
                }
            else {
                inEco = 2;
                }
        case 'G':
            if( random <= 15){
                inEco = 0;
                }
            else if( random <= 70 ){
                inEco = 1;
                }
            else if( random <= 95 ){
                inEco = 2;
                }
            else {
                inEco = 3;
                }
        case 'K':
            if( random <= 30){
                inEco = 1;
                }
            else if( random <= 85 ){
                inEco = 2;
                }
            else if( random <= 95 ){
                inEco = 3;
                }
            else {
                inEco = 4;
                }
        case 'M':
            if( random <= 30){
                inEco = 0;
                }
            else if( random <= 95 ){
                inEco = 1;
                }
            else {
                inEco = 2;
                }
        }

    //inEco = 9;     // TESTING REMOVE

    this->planetsInEcosphere = inEco;
    for(int i=0, j=0; i < this->naturalSatellitesHabitable && j < inEco; i++){
        if(this->planet[i].type == Rock){
            this->planet[i].inStellarEcosphere = 1;
            j++;
            }
        }

    return 0;
    }


int StarSystem::satelliteEnvironmentFind(){
    int rollH, rollC, rollB = 0;
    int bioMod = 0;
    for(int i=0; i < this->naturalSatellitesHabitable; i++){
        rollH = 0;
        rollC = 0;
        rollB = 0;
        if(this->planet[i].inStellarEcosphere == 1){
            //Atmosphere
            int random = randomDieOpenEnded(1);
            if(random <= 0){
                this->planet[i].paramAtmos = 1;
                }
            else if(random <= 20){
                this->planet[i].paramAtmos = 2;
                }
            else if(random <= 40){
                this->planet[i].paramAtmos = 3;
                }
            else if(random <= 60){
                this->planet[i].paramAtmos = 4;
                }
            else if(random <= 80){
                this->planet[i].paramAtmos = 5;
                }
            else if(random <= 100){
                this->planet[i].paramAtmos = 6;
                }
            else if(random <= 150){
                this->planet[i].paramAtmos = 7;
                rollH = 1;
                }
            else if(random <= 239){
                this->planet[i].paramAtmos = 8;
                rollH = 1;
                }
            else if(random <= 249){
                this->planet[i].paramAtmos = 9;
                rollH = 1;
                bioMod = 100;
                }
            else{
                this->planet[i].paramAtmos = 10;
                rollH = 1;
                bioMod = 100;
                }
            
            if(rollH == 1){
                //Hydrosphere
                random = randomDieOpenEnded(1);
                if(random <= 0){
                    this->planet[i].paramHydro = 1;
                    }
                else if(random <= 20){
                    this->planet[i].paramHydro = 2;
                    rollC = 1;
                    }
                else if(random <= 40){
                    this->planet[i].paramHydro = 3;
                    rollC = 1;
                    }
                else if(random <= 60){
                    this->planet[i].paramHydro = 4;
                    rollC = 1;
                    }
                else if(random <= 80){
                    this->planet[i].paramHydro = 5;
                    rollC = 1;
                    }
                else if(random <= 100){
                    this->planet[i].paramHydro = 6;
                    rollC = 1;
                    }
                else if(random <= 150){
                    this->planet[i].paramHydro = 7;
                    rollC = 1;
                    }
                else if(random <= 239){
                    this->planet[i].paramHydro = 8;
                    rollC = 1;
                    }
                else if(random <= 249){
                    this->planet[i].paramHydro = 9;
                    rollC = 1;
                    }
                else{
                    this->planet[i].paramHydro = 10;
                    rollC = 1;
                 }

            if(rollC == 1){
                //Climate
                random = randomDieOpenEnded(1);
                if(random <= 0){
                    this->planet[i].paramClima = 1;
                    }
                else if(random <= 20){
                    this->planet[i].paramClima = 2;
                    rollB = 1;
                    }
                else if(random <= 40){
                    this->planet[i].paramClima = 3;
                    rollB = 1;
                    }
                else if(random <= 60){
                    this->planet[i].paramClima = 4;
                    rollB = 1;
                    }
                else if(random <= 80){
                    this->planet[i].paramClima = 5;
                    rollB = 1;
                    }
                else if(random <= 100){
                    this->planet[i].paramClima = 6;
                    rollB = 1;
                    }
                else if(random <= 150){
                    this->planet[i].paramClima = 7;
                    }
                else if(random <= 239){
                    this->planet[i].paramClima = 8;
                    }
                else if(random <= 249){
                    this->planet[i].paramClima = 9;
                    rollB = 1;
                    }
                else{
                    this->planet[i].paramClima = 10;
                 }

            if(rollB == 1){
                //Biosphere
                random = randomDieOpenEnded(1) + bioMod;
                if(random <= 0){
                    this->planet[i].paramBiosp = 1;
                    }
                else if(random <= 20){
                    this->planet[i].paramBiosp = 2;
                    }
                else if(random <= 40){
                    this->planet[i].paramBiosp = 3;
                    }
                else if(random <= 60){
                    this->planet[i].paramBiosp = 4;
                    }
                else if(random <= 80){
                    this->planet[i].paramBiosp = 5;;
                    }
                else if(random <= 100){
                    this->planet[i].paramBiosp = 6;
                    }
                else if(random <= 150){
                    this->planet[i].paramBiosp = 7;
                    }
                else if(random <= 239){
                    this->planet[i].paramBiosp = 8;
                    }
                else if(random <= 249){
                    this->planet[i].paramBiosp = 9;
                    }
                else{
                    this->planet[i].paramBiosp = 10;
                    }
                } else {
                    this->planet[i].paramBiosp = 0;
                    }
                } else {
                    this->planet[i].paramClima = 0;
                    this->planet[i].paramBiosp = 0;
                    }
} else {
    this->planet[i].paramHydro = 0;
    this->planet[i].paramClima = 0;
    this->planet[i].paramBiosp = 0;
    }
} else {
    this->planet[i].paramAtmos = 0;
    this->planet[i].paramHydro = 0;
    this->planet[i].paramClima = 0;
    this->planet[i].paramBiosp = 0;
    }
}

    return 0;
    }



int StarSystem::satelliteGravityFind(){
    double rCirc;
    for(int i = 0; i < this->naturalSatellitesHabitable; i++){
        rCirc = (int)ceil(this->planet[i].baseCirc) * pow(10, this->planet[i].circExponent) * this->planet[i].density;
        printf(" Round Circ for %f x 10^%d = %d\n", this->planet[i].baseCirc, this->planet[i].circExponent, rCirc);
        if( rCirc <= 3e3 ){
            this->planet[i].baseGravity = 0;
            }
        else if( rCirc <= 4e3 ){
            this->planet[i].baseGravity = .1;
            }
        else if( rCirc <= 5e3 ){
            this->planet[i].baseGravity = .12;
            }
        else if( rCirc <= 6e3 ){
            this->planet[i].baseGravity = .15;
            }
        else if( rCirc <= 7e3 ){
            this->planet[i].baseGravity = .18;
            }
        else if( rCirc <= 8e3 ){
            this->planet[i].baseGravity = .2;
            }
        else if( rCirc <= 9e3 ){
            this->planet[i].baseGravity = .22;
            }
        else if( rCirc <= 1e4 ){
            this->planet[i].baseGravity = .25;
            }
        else if( rCirc <= 2e4 ){
            this->planet[i].baseGravity = .5;
            }
        else if( rCirc <= 3e4 ){
            this->planet[i].baseGravity = .75;
            }
        else if( rCirc <= 4e4 ){
            this->planet[i].baseGravity = 1;
            }
        else if( rCirc <= 5e4 ){
            this->planet[i].baseGravity = 1.25;
            }
        else if( rCirc <= 6e4 ){
            this->planet[i].baseGravity = 1.5;
            }
        else if( rCirc <= 7e4 ){
            this->planet[i].baseGravity = 1.75;
            }
        else if( rCirc <= 8e4 ){
            this->planet[i].baseGravity = 2;
            }
        else if( rCirc <= 9e4 ){
            this->planet[i].baseGravity = 2.25;
            }
        else if( rCirc <= 1e5 ){
            this->planet[i].baseGravity = 2.5;
            }
        else if( rCirc <= 2e5 ){
            this->planet[i].baseGravity = 4.25;
            }
        else if( rCirc <= 3e5 ){
            this->planet[i].baseGravity = 6.5;
            }
        else if( rCirc <= 4e5 ){
            this->planet[i].baseGravity = 8.5;
            }
        else if( rCirc <= 5e5 ){
            this->planet[i].baseGravity = 10;
            }
        else if( rCirc <= 6e5 ){
            this->planet[i].baseGravity = 13;
            }
        else if( rCirc <= 7e5 ){
            this->planet[i].baseGravity = 15;
            }
        else if( rCirc <= 8e5 ){
            this->planet[i].baseGravity = 17;
            }
        else if( rCirc <= 9e5 ){
            this->planet[i].baseGravity = 19;
            }

        }
    return 0;
    }

int StarSystem::satelliteDensityFind(){
    int random;
    double total = 1;
    for(int i = 0; i < this->naturalSatellitesHabitable; i++){
        if( this->planet[i].type == Rock ){
            random = randomDie(10, 2);
            if(random < 20){
                //Planet is very small
                total = (double)(random * .1);
                }
            else {
                while( random == 20 ){
                    total += 10;
                    random = randomDie(10, 2);
                    }
                total += random;
                total = total * .1;
                }
            this->planet[i].density = total;
            }
        else if( this->planet[i].type == Gas ){
            random = randomDie(10, 2);
            if(random < 20){
                //Planet is very small
                total = random * .02;
                }
            else {
                while( random == 20 ){
                    total += 10;
                    random = randomDie(10, 2);
                    }
                total += random;
                total = total * .02;
                }
            this->planet[i].density = total;
            }
        else{
            this->planet[i].density = 0;
            }

        }
    return 0;
    }

int StarSystem::stellarTypeChart()
{
    /* Stellar Type Chart
    * Roll          Result
    * 1-6           (V) Main sequence star
    * 7             (IV) Sub-giant
    * 8             (III) Giant
    * 9             (II) Bright-giant
    * 10            (I) Super-giant
    */

    int roll = randomDie(10, 1);
    int stellarType = -1;
    
    if( roll <= 6 ){
        stellarType = 5;
        }
    else if( roll <= 7 ){
        stellarType = 4;
        }
    else if( roll <= 8 ){
        stellarType = 3;
        }
    else if( roll <= 9 ){
        stellarType = 2;
        }
    else if( roll <= 10 ){
        stellarType = 1;
        }
    return stellarType;

    }

int StarSystem::satelliteCirc(){
    double baseCirc;
    for(int i = 0; i < this->naturalSatellitesHabitable; i++){
        if( this->planet[i].type == Rock ){
            baseCirc = (randomDieOpenEnded(0) + randomDieOpenEnded(0))/2;
            if(baseCirc < 20){
                //Planet is very small
                this->planet[i].baseCirc = baseCirc/2;
                this->planet[i].circExponent = 3;
                }
            else if(baseCirc < 200){
                this->planet[i].baseCirc = baseCirc/20;
                this->planet[i].circExponent = 4;
                }
            else{
                //Planet is very large
                this->planet[i].baseCirc = baseCirc/200;
                this->planet[i].circExponent = 5;
                }
            }
        else if( this->planet[i].type == Gas ){
            baseCirc = (randomDie(10, 2) / 2)+(this->massVsSol/4);
            if(baseCirc < 2){
                //Gas giant is very small
                this->planet[i].baseCirc = baseCirc * 5;
                this->planet[i].circExponent = 4;
                }
            else {
                this->planet[i].baseCirc = baseCirc/2;
                this->planet[i].circExponent = 5;
                }
            }
        else{
            this->planet[i].baseCirc = 0;
            this->planet[i].circExponent = 0;
            }
        }
    return 0;


    }

int StarSystem::satelliteInfoFind(){
    this->naturalSatelliteDetermination();
    this->planetsInEcosphere = 0;
    if(this->naturalSatellitesHabitable > 0){
        this->planet = new Planet[this->naturalSatellitesHabitable];

        this->orbitalRadiusFind();
        printf(" *STUB* Orbital Radius Found\n");
        this->satelliteTypeFind();
        printf(" *STUB* Satellite Type Found\n");
        this->satelliteCirc();
        this->satelliteDensityFind();
        this->satelliteGravityFind();
        this->satelliteAtmosphereFind();
        this->satelliteEnvironmentFind();
        }
    return 0;
    }



int StarSystem::stellarMassFind(){
    if( this->brightnessVsSol < .001) {
        this->massVsSol = (.0167);
        }
    else if( this->brightnessVsSol < .01) {
        this->massVsSol = (.0667);
        }
    else if( this->brightnessVsSol < .05) {
        this->massVsSol = (.2);
        }
    else if( this->brightnessVsSol < .1) {
        this->massVsSol = (.333);
        }
    else if( this->brightnessVsSol < 1) {
        this->massVsSol = (1);
        }
    else if( this->brightnessVsSol < 10) {
        this->massVsSol = (2);
        }
    else if( this->brightnessVsSol < 100) {
        this->massVsSol = (3);
        }
    else if( this->brightnessVsSol < 1000) {
        this->massVsSol = (4);
        }
    else if( this->brightnessVsSol < 10000) {
        this->massVsSol = (6);
        }
    else if( this->brightnessVsSol < 100000) {
        this->massVsSol = (10);
        }
    else if( this->brightnessVsSol < 1000000) {
        this->massVsSol = (30);
        }

    return 0;
    }


int StarSystem::stellarBodyFrequency(){
    /* Stellar Body Frequency Chart
    * Roll          Class / Stellar Notes
    * 01-75         M (0-9)
    * 71-81         K (0-9)
    * 82-86         G (0-9)
    * 87-95         F (0-9)
    * 96-120        Cluster  Roll for 1-5 random stars with significant gravitational influence on one another
    * 121-140       B (0-9)
    * 141-160       O (0-9)
    * 161-180       N (0-9)
    * 181-200       S (0-9)
    * 201->         Phenomenon Mostly brown dwarfs, but also includes black holes, neutron, dwarf, pulsar and variable
    *               stars, and nebulae
    */



    int brightness = -1;
    int stellarType = -1;
    int random = randomDieOpenEnded(0);
    if( random >= 201 ){
        printf( " Phenomenon Mostly brown dwarfs, but also includes black holes, neutron, dwarf, pulsar and variable stars, and nebulae\n" );
        this->starClass = 'P';
        }
    else if( random >= 161 ){
            brightness = randomDie(10, 1)-1;
            stellarType = stellarTypeChart();
            //printf( " Class N star, brightness %d\n", brightness);
            this->starClass = 'N';
            this->brightness = brightness;
            this->stellarType = stellarType;
        }
    else if( random >= 141 ){
            brightness = randomDie(10, 1)-1;
            stellarType = stellarTypeChart();
            //printf( " Class O star, brightness %d\n", brightness);
            this->starClass = 'O';
            this->brightness = brightness;
            this->stellarType = stellarType;
        }
    else if( random >= 121 ){
            brightness = randomDie(10, 1)-1;
            stellarType = stellarTypeChart();
            //printf( " Class B star, brightness %d\n", brightness);
            this->starClass = 'B';
            this->brightness = brightness;
            this->stellarType = stellarType;
        }
    else if( random >= 96 ){
            brightness = randomDie(5, 1);
            stellarType = stellarTypeChart();
            printf( " Cluster, %d stars with significant gravitational influence on one another\n", brightness);
                        this->starClass = 'C';
            this->brightness = brightness;
            this->stellarType = stellarType;
        }
    else if( random >= 87 ){
            brightness = randomDie(10, 1)-1;
            stellarType = stellarTypeChart();
            //printf( " Class F star, brightness %d\n", brightness);
            this->starClass = 'F';
            this->brightness = brightness;
            this->stellarType = stellarType;
        }
    else if( random >= 82 ){
            brightness = randomDie(10, 1)-1;
            stellarType = stellarTypeChart();
            //printf( " Class G star, brightness %d\n", brightness);
            this->starClass = 'G';
            this->brightness = brightness;
            this->stellarType = stellarType;
    }
    else if( random >= 71 ){
            brightness = randomDie(10, 1)-1;
            stellarType = stellarTypeChart();
            while(stellarType == 4){
                stellarType = stellarTypeChart();
                }
            //printf( " Class K star, brightness %d\n", brightness);
            this->starClass = 'K';
            this->brightness = brightness;
            this->stellarType = stellarType;
    }
    else if( random >= 1 ){
            brightness = randomDie(10, 1)-1;
            stellarType = stellarTypeChart();
            while(stellarType == 4){
                stellarType = stellarTypeChart();
                }
            //printf( " Class M star, brightness %d\n", brightness);
            this->starClass = 'M';
            this->brightness = brightness;
            this->stellarType = stellarType;
    }
    else 
        printf( " error: number out of bounds ");

    return 0;
}

double StarSystem::radiusVsSolGet(){
    return(radiusVsSol);
    }

int StarSystem::naturalSatellitesGet(){
    return(naturalSatellites);
    }

int StarSystem::starDescNumberGet(){
    return(starDescNumber);
    }

int StarSystem::hertzprungRusselDiagram(){

    switch(this->starClass){
        case 'O':
            if(this->stellarType == 5){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 1000000;
                    this->radiusVsSol = 6;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 100000;
                    this->radiusVsSol = 3;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                else{
                    this->brightnessVsSol = 10000;
                    this->radiusVsSol = 2;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                }
            else if(this->stellarType == 4){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 1000000;
                    this->radiusVsSol = 9;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 500000;
                    this->radiusVsSol = 6;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                else{
                    this->brightnessVsSol = 100000;
                    this->radiusVsSol = 3;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                }
            else if(this->stellarType == 3){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 1000000;
                    this->radiusVsSol = 9;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 500000;
                    this->radiusVsSol = 6;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                else{
                    this->brightnessVsSol = 100000;
                    this->radiusVsSol = 3;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                }
            else if(this->stellarType == 2){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 1000000;
                    this->radiusVsSol = 9;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 500000;
                    this->radiusVsSol = 6;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                else{
                    this->brightnessVsSol = 100000;
                    this->radiusVsSol = 3;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                }
            else if(this->stellarType == 1){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 4000000;
                    this->radiusVsSol = 12;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 2000000;
                    this->radiusVsSol = 18;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                else{
                    this->brightnessVsSol = 1000000;
                    this->radiusVsSol = 24;
                    this->starDescNumber = 0;
                    strcpy(this->starDesc, "Extremely bright blue-white");
                    }
                }
            break;
        case 'B':
            if(this->stellarType == 5){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 8000;
                    this->radiusVsSol = 2;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 4000;
                    this->radiusVsSol = 1.6;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                else{
                    this->brightnessVsSol = 900;
                    this->radiusVsSol = 1.2;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                }
            else if(this->stellarType == 4){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 40000;
                    this->radiusVsSol = 3;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 9000;
                    this->radiusVsSol = 2.6;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                else{
                    this->brightnessVsSol = 5000;
                    this->radiusVsSol = 2;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                }
            else if(this->stellarType == 3){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 40000;
                    this->radiusVsSol = 3;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 9000;
                    this->radiusVsSol = 3;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                else{
                    this->brightnessVsSol = 6000;
                    this->radiusVsSol = 3;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                }
            else if(this->stellarType == 2){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 80000;
                    this->radiusVsSol = 5;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 50000;
                    this->radiusVsSol = 5;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                else{
                    this->brightnessVsSol = 20000;
                    this->radiusVsSol = 5.5;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                }
            else if(this->stellarType == 1){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 1000000;
                    this->radiusVsSol = 20;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 600000;
                    this->radiusVsSol = 20;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                else{
                    this->brightnessVsSol = 300000;
                    this->radiusVsSol = 21;
                    this->starDescNumber = 1;
                    strcpy(this->starDesc, "Very bright blue-white");
                    }
                }
            break;
            case 'A':
            if(this->stellarType == 5){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 500;
                    this->radiusVsSol = 1;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 100;
                    this->radiusVsSol = 1;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                else{
                    this->brightnessVsSol = 60;
                    this->radiusVsSol = .9;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                }
            else if(this->stellarType == 4){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 1000;
                    this->radiusVsSol = 2;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 600;
                    this->radiusVsSol = 2;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                else{
                    this->brightnessVsSol = 200;
                    this->radiusVsSol = 2;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                }
            else if(this->stellarType == 3){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 5000;
                    this->radiusVsSol = 4;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 3000;
                    this->radiusVsSol = 4;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                else{
                    this->brightnessVsSol = 900;
                    this->radiusVsSol = 4;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                }
            else if(this->stellarType == 2){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 9000;
                    this->radiusVsSol = 7;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 9500;
                    this->radiusVsSol = 5;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                else{
                    this->brightnessVsSol = 10000;
                    this->radiusVsSol = 5.5;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                }
            else if(this->stellarType == 1){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 200000;
                    this->radiusVsSol = 27;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 100000;
                    this->radiusVsSol = 30;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                else{
                    this->brightnessVsSol = 90000;
                    this->radiusVsSol = 40;
                    this->starDescNumber = 2;
                    strcpy(this->starDesc, "Blue-white");
                    }
                }
            break;
            case 'F':
            if(this->stellarType == 5){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 10;
                    this->radiusVsSol = .7;
                    this->starDescNumber = 3;
                    strcpy(this->starDesc, "Bluish white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 5;
                    this->radiusVsSol = .7;
                    this->starDescNumber = 4;
                    strcpy(this->starDesc, "White");
                    }
                else{
                    this->brightnessVsSol = 3;
                    this->radiusVsSol = .7;
                    this->starDescNumber = 5;
                    strcpy(this->starDesc, "Yellowish white");
                    }
                }
            else if(this->stellarType == 4){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 100;
                    this->radiusVsSol = 2;
                    this->starDescNumber = 3;
                    strcpy(this->starDesc, "Bluish white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 90;
                    this->radiusVsSol = 2.6;
                    this->starDescNumber = 4;
                    strcpy(this->starDesc, "White");
                    }
                else{
                    this->brightnessVsSol = 50;
                    this->radiusVsSol = 3;
                    this->starDescNumber = 5;
                    strcpy(this->starDesc, "Yellowish white");
                    }
                }
            else if(this->stellarType == 3){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 700;
                    this->radiusVsSol = 3;
                    this->starDescNumber = 3;
                    strcpy(this->starDesc, "Bluish white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 200;
                    this->radiusVsSol = 3.3;
                    this->starDescNumber = 4;
                    strcpy(this->starDesc, "White");
                    }
                else{
                    this->brightnessVsSol = 160;
                    this->radiusVsSol = 7;
                    this->starDescNumber = 5;
                    strcpy(this->starDesc, "Yellowish white");
                    }
                }
            else if(this->stellarType == 2){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 5000;
                    this->radiusVsSol = 10;
                    this->starDescNumber = 3;
                    strcpy(this->starDesc, "Bluish white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 4000;
                    this->radiusVsSol = 15;
                    this->starDescNumber = 4;
                    strcpy(this->starDesc, "White");
                    }
                else{
                    this->brightnessVsSol = 2000;
                    this->radiusVsSol = 20;
                    this->starDescNumber = 5;
                    strcpy(this->starDesc, "Yellowish white");
                    }
                }
            else if(this->stellarType == 1){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 80000;
                    this->radiusVsSol = 40;
                    this->starDescNumber = 3;
                    strcpy(this->starDesc, "Bluish white");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 60000;
                    this->radiusVsSol = 60;
                    this->starDescNumber = 4;
                    strcpy(this->starDesc, "White");
                    }
                else{
                    this->brightnessVsSol = 30000;
                    this->radiusVsSol = 80;
                    this->starDescNumber = 5;
                    strcpy(this->starDesc, "Yellowish white");
                    }
                }
            break;
            case 'G':
            if(this->stellarType == 5){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 1;
                    this->radiusVsSol = .7;
                    this->starDescNumber = 6;
                    strcpy(this->starDesc, "Whitish yellow");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = .5;
                    this->radiusVsSol = .6;
                    this->starDescNumber = 7;
                    strcpy(this->starDesc, "Yellow");
                    }
                else{
                    this->brightnessVsSol = .1;
                    this->radiusVsSol = .5;
                    this->starDescNumber = 8;
                    strcpy(this->starDesc, "Orangish yellow");
                    }
                }
            else if(this->stellarType == 4){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 50;
                    this->radiusVsSol = 3;
                    this->starDescNumber = 6;
                    strcpy(this->starDesc, "Whitish yellow");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 30;
                    this->radiusVsSol = 4;
                    this->starDescNumber = 7;
                    strcpy(this->starDesc, "Yellow");
                    }
                else{
                    this->brightnessVsSol = 11;
                    this->radiusVsSol = 6;
                    this->starDescNumber = 8;
                    strcpy(this->starDesc, "Orangish yellow");
                    }
                }
            else if(this->stellarType == 3){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 200;
                    this->radiusVsSol = 9;
                    this->starDescNumber = 6;
                    strcpy(this->starDesc, "Whitish yellow");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 300;
                    this->radiusVsSol = 20;
                    this->starDescNumber = 7;
                    strcpy(this->starDesc, "Yellow");
                    }
                else{
                    this->brightnessVsSol = 400;
                    this->radiusVsSol = 26;
                    this->starDescNumber = 8;
                    strcpy(this->starDesc, "Orangish yellow");
                    }
                }
            else if(this->stellarType == 2){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 2000;
                    this->radiusVsSol = 25;
                    this->starDescNumber = 6;
                    strcpy(this->starDesc, "Whitish yellow");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 2000;
                    this->radiusVsSol = 30;
                    this->starDescNumber = 7;
                    strcpy(this->starDesc, "Yellow");
                    }
                else{
                    this->brightnessVsSol = 2000;
                    this->radiusVsSol = 50;
                    this->starDescNumber = 8;
                    strcpy(this->starDesc, "Orangish yellow");
                    }
                }
            else if(this->stellarType == 1){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 30000;
                    this->radiusVsSol = 100;
                    this->starDescNumber = 6;
                    strcpy(this->starDesc, "Whitish yellow");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 20000;
                    this->radiusVsSol = 140;
                    this->starDescNumber = 7;
                    strcpy(this->starDesc, "Yellow");
                    }
                else{
                    this->brightnessVsSol = 11000;
                    this->radiusVsSol = 200;
                    this->starDescNumber = 8;
                    strcpy(this->starDesc, "Orangish yellow");
                    }
                }
            break;
            case 'K':
            if(this->stellarType == 5){
                if(this->brightness <= 3){
                    this->brightnessVsSol = .07;
                    this->radiusVsSol = .5;
                    this->starDescNumber = 9;
                    strcpy(this->starDesc, "Yellowish orange");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = .01;
                    this->radiusVsSol = .3;
                    this->starDescNumber = 10;
                    strcpy(this->starDesc, "Orange");
                    }
                else{
                    this->brightnessVsSol = .008;
                    this->radiusVsSol = .26;
                    this->starDescNumber = 11;
                    strcpy(this->starDesc, "Reddish orange");
                    }
                }
            else if(this->stellarType == 4){
                if(this->brightness <= 3){
                    this->brightnessVsSol = -1;
                    this->radiusVsSol = -1;
                    this->starDescNumber = 9;
                    strcpy(this->starDesc, "Yellowish orange");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = -1;
                    this->radiusVsSol = -1;
                    this->starDescNumber = 10;
                    strcpy(this->starDesc, "Orange");
                    }
                else{
                    this->brightnessVsSol = -1;
                    this->radiusVsSol = -1;
                    this->starDescNumber = 11;
                    strcpy(this->starDesc, "Reddish orange");
                    }
                }
            else if(this->stellarType == 3){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 500;
                    this->radiusVsSol = 35;
                    this->starDescNumber = 9;
                    strcpy(this->starDesc, "Yellowish orange");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 700;
                    this->radiusVsSol = 80;
                    this->starDescNumber = 10;
                    strcpy(this->starDesc, "Orange");
                    }
                else{
                    this->brightnessVsSol = 900;
                    this->radiusVsSol = 160;
                    this->starDescNumber = 11;
                    strcpy(this->starDesc, "Reddish orange");
                    }
                }
            else if(this->stellarType == 2){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 1200;
                    this->radiusVsSol = 90;
                    this->starDescNumber = 9;
                    strcpy(this->starDesc, "Yellowish orange");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 1700;
                    this->radiusVsSol = 120;
                    this->starDescNumber = 10;
                    strcpy(this->starDesc, "Orange");
                    }
                else{
                    this->brightnessVsSol = 1900;
                    this->radiusVsSol = 260;
                    this->starDescNumber = 11;
                    strcpy(this->starDesc, "Reddish orange");
                    }
                }
            else if(this->stellarType == 1){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 13000;
                    this->radiusVsSol = 240;
                    this->starDescNumber = 9;
                    strcpy(this->starDesc, "Yellowish orange");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 13000;
                    this->radiusVsSol = 300;
                    this->starDescNumber = 10;
                    strcpy(this->starDesc, "Orange");
                    }
                else{
                    this->brightnessVsSol = 13000;
                    this->radiusVsSol = 500;
                    this->starDescNumber = 11;
                    strcpy(this->starDesc, "Reddish orange");
                    }
                }
            break;
            case 'M':
            if(this->stellarType == 5){
                if(this->brightness <= 3){
                    this->brightnessVsSol = .001;
                    this->radiusVsSol = .25;
                    this->starDescNumber = 12;
                    strcpy(this->starDesc, "Orangish red");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = .0005;
                    this->radiusVsSol = .2;
                    this->starDescNumber = 13;
                    strcpy(this->starDesc, "Bright red");
                    }
                else{
                    this->brightnessVsSol = .00007;
                    this->radiusVsSol = .1;
                    this->starDescNumber = 13;
                    strcpy(this->starDesc, "Bright red");
                    }
                }
            else if(this->stellarType == 4){
                if(this->brightness <= 3){
                    this->brightnessVsSol = -1;
                    this->radiusVsSol = -1;
                    this->starDescNumber = 12;
                    strcpy(this->starDesc, "Orangish red");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = -1;
                    this->radiusVsSol = -1;
                    this->starDescNumber = 13;
                    strcpy(this->starDesc, "Bright red");
                    }
                else{
                    this->brightnessVsSol = -1;
                    this->radiusVsSol = -1;
                    this->starDescNumber = 13;
                    strcpy(this->starDesc, "Bright red");
                    }
                }
            else if(this->stellarType == 3){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 900;
                    this->radiusVsSol = 370;
                    this->starDescNumber = 12;
                    strcpy(this->starDesc, "Orangish red");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 1000;
                    this->radiusVsSol = 300;
                    this->starDescNumber = 13;
                    strcpy(this->starDesc, "Bright red");
                    }
                else{
                    this->brightnessVsSol = 1000;
                    this->radiusVsSol = 200;
                    this->starDescNumber = 13;
                    strcpy(this->starDesc, "Bright red");
                    }
                }
            else if(this->stellarType == 2){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 2000;
                    this->radiusVsSol = 370;
                    this->starDescNumber = 12;
                    strcpy(this->starDesc, "Orangish red");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 2000;
                    this->radiusVsSol = 500;
                    this->starDescNumber = 13;
                    strcpy(this->starDesc, "Bright red");
                    }
                else{
                    this->brightnessVsSol = 2300;
                    this->radiusVsSol = 900;
                    this->starDescNumber = 13;
                    strcpy(this->starDesc, "Bright red");
                    }
                }
            else if(this->stellarType == 1){
                if(this->brightness <= 3){
                    this->brightnessVsSol = 11000;
                    this->radiusVsSol = 900;
                    this->starDescNumber = 12;
                    strcpy(this->starDesc, "Orangish red");
                    }
                else if(this->brightness <= 6){
                    this->brightnessVsSol = 11000;
                    this->radiusVsSol = 1000;
                    this->starDescNumber = 13;
                    strcpy(this->starDesc, "Bright red");
                    }
                else{
                    this->brightnessVsSol = 11500;
                    this->radiusVsSol = 2000;
                    this->starDescNumber = 13;
                    strcpy(this->starDesc, "Bright red");
                    }
                }
            break;
            case 'N':
            if(this->stellarType <= 5){
                if(this->brightness <= 3){
                    this->starDescNumber = 14;
                    strcpy(this->starDesc, "Deep red");
                    }
                else if(this->brightness <= 6){
                    this->starDescNumber = 14;
                    strcpy(this->starDesc, "Deep red");
                    }
                else{
                    this->starDescNumber = 15;
                    strcpy(this->starDesc, "Dull red");
                    }
                }
            break;
            case 'S':
            if(this->stellarType <= 5){
                if(this->brightness <= 9){
                    this->starDescNumber = 16;
                    strcpy(this->starDesc, "Dim red");
                    }
                }
            break;
            }

        return 0;
}

int StarSystem::gravityWellFind(){
    this->gravityWell = (this->radiusVsSol * 3.74);
    return 0;
    }

int StarSystem::orbitalRadiusFind(){
    double multiplier = -1;

    switch(this->starClass){
        case 'O': if(this->stellarType <= 1){
                multiplier = 100;
                }
            else if(this->stellarType <= 2){
                multiplier = 50;
                }
            else if(this->stellarType <= 3){
                multiplier = 45;
                }
            else if(this->stellarType <= 4){
                multiplier = 30;
                }
            else{
                multiplier = 20;
                }
            break;
        case 'B': if(this->stellarType <= 1){
                multiplier = 70;
                }
            else if(this->stellarType <= 2){
                multiplier = 30;
                }
            else if(this->stellarType <= 3){
                multiplier = 30;
                }
            else if(this->stellarType <= 4){
                multiplier = 25;
                }
            else{
                multiplier = 15;
                }
            break;
        case 'A': if(this->stellarType <= 1){
                multiplier = 30;
                }
            else if(this->stellarType <= 2){
                multiplier = 4;
                }
            else if(this->stellarType <= 3){
                multiplier = 2;
                }
            else if(this->stellarType <= 4){
                multiplier = 1.5;
                }
            else{
                multiplier = 1;
                }
            break;
        case 'F': if(this->stellarType <= 1){
                multiplier = 20;
                }
            else if(this->stellarType <= 2){
                multiplier = 3;
                }
            else if(this->stellarType <= 3){
                multiplier = 2;
                }
            else if(this->stellarType <= 4){
                multiplier = 1;
                }
            else{
                multiplier = 1;
                }
            break;
        case 'G': if(this->stellarType <= 1){
                multiplier = 30;
                }
            else if(this->stellarType <= 2){
                multiplier = 4;
                }
            else if(this->stellarType <= 3){
                multiplier = 2;
                }
            else if(this->stellarType <= 4){
                multiplier = 1;
                }
            else{
                multiplier = 1;
                }
            break;
        case 'K': if(this->stellarType <= 1){
                multiplier = 35;
                }
            else if(this->stellarType <= 2){
                multiplier = 5;
                }
            else if(this->stellarType <= 3){
                multiplier = 2;
                }
            else if(this->stellarType <= 4){
                multiplier = 1;
                }
            else{
                multiplier = 1;
                }
            break;
        case 'M': if(this->stellarType <= 1){
                multiplier = 60;
                }
            else if(this->stellarType <= 2){
                multiplier = 20;
                }
            else if(this->stellarType <= 3){
                multiplier = 10;
                }
            else if(this->stellarType <= 4){
                multiplier = 1;
                }
            else{
                multiplier = 1;
                }
            break;
        case 'N': if(this->stellarType <= 1){
                multiplier = 60;
                }
            else if(this->stellarType <= 2){
                multiplier = 25;
                }
            else if(this->stellarType <= 3){
                multiplier = 12;
                }
            else if(this->stellarType <= 4){
                multiplier = 1;
                }
            else{
                multiplier = 1;
                }
            break;
        case 'S': if(this->stellarType <= 1){
                multiplier = 60;
                }
            else if(this->stellarType <= 2){
                multiplier = 30;
                }
            else if(this->stellarType <= 3){
                multiplier = 15;
                }
            else if(this->stellarType <= 4){
                multiplier = 1;
                }
            else{
                multiplier = 1;
                }
            break;

        }

    printf(" *STUB* Orbit Multiplier: %f\n", multiplier);


    double baseOR = randomDie(10, 4) * (multiplier / 100.0);
    printf(" *STUB* Base Orbit: %f\n", baseOR);
    double lastOR = baseOR;
    for(int i = 0; i < this->naturalSatellitesHabitable; i++){
        this->planet[i].planetNumber = i;
        this->planet[i].orbitalRadius = lastOR;
        lastOR *= (randomDie(10, 2)/10)+1.4;
    printf(" *STUB* Last Orbit: %f\n", lastOR);
        this->planet[i].orbitalSpeed = randomDie(120, 1);
        this->planet[i].rotationalSpeed = randomDie(120, 1);
        }
    return 0;
    }


int StarSystem::satelliteTypeFind(){
    double location;
    int random;
    for(int i = 0; i < this->naturalSatellitesHabitable; i++){
        location = (i+1)*100/this->naturalSatellitesHabitable;
        random = randomDie(100, 1);
        if(location <= 20){
            //printf(" *STUB* Location <= 20\n");
            if(random <= 15){
                this->planet[i].type = Asteroid;
                }
            else if(random <= 30){
                random = randomDie(10, 1);
                this->planet[i].type = Rock;
                }
            else if(random <= 70){
                this->planet[i].type = Rock;
                }
            else if(random <= 85){
                this->planet[i].type = Rock;
                }
            else if(random <= 95){
                this->planet[i].type = Rock;
                }
            else{
                this->planet[i].type = Empty;
                }
            }
        else if(location <= 40){
            //printf(" *STUB* Location <= 40\n");
            if(random <= 15){
                this->planet[i].type = Rock;
                }
            else if(random <= 30){
                random = randomDie(10, 1);
                this->planet[i].type = Asteroid;
                }
            else if(random <= 70){
                this->planet[i].type = Rock;
                }
            else if(random <= 85){
                this->planet[i].type = Rock;
                }
            else if(random <= 95){
                this->planet[i].type = Gas;
                }
            else{
                this->planet[i].type = Empty;
                }
            }
        else if(location <= 60){
            //printf(" *STUB* Location <= 60\n");
            if(random <= 15){
                this->planet[i].type = Rock;
                }
            else if(random <= 30){
                random = randomDie(10, 1);
                this->planet[i].type = Rock;
                }
            else if(random <= 70){
                this->planet[i].type = Asteroid;
                }
            else if(random <= 85){
                this->planet[i].type = Gas;
                }
            else if(random <= 95){
                this->planet[i].type = Gas;
                }
            else{
                this->planet[i].type = Empty;
                }
            }
        else if(location <= 80){
            //printf(" *STUB* Location <= 80\n");
            if(random <= 15){
                this->planet[i].type = Rock;
                }
            else if(random <= 30){
                random = randomDie(10, 1);
                this->planet[i].type = Rock;
                }
            else if(random <= 70){
                this->planet[i].type = Gas;
                }
            else if(random <= 85){
                this->planet[i].type = Asteroid;
                }
            else if(random <= 95){
                this->planet[i].type = Gas;
                }
            else{
                this->planet[i].type = Empty;
                }
            }
        else if(location <= 100){
            //printf(" *STUB* Location <= 100\n");
            if(random <= 15){
                this->planet[i].type = Rock;
                }
            else if(random <= 30){
                random = randomDie(10, 1);
                this->planet[i].type = Gas;
                }
            else if(random <= 70){
                this->planet[i].type = Gas;
                }
            else if(random <= 85){
                this->planet[i].type = Gas;
                }
            else if(random <= 95){
                this->planet[i].type = Rock;
                }
            else{
                this->planet[i].type = Empty;
                }
            }
    switch(this->planet[i].type){
        case Rock:
            printf(" Satellite Type = Rock Planet\n");
            break;
        case Gas:
            printf(" Satellite Type = Gas Giant\n");
            break;
        case Asteroid:
            printf(" Satellite Type = Asteroid Field\n");
            break;
        case Empty:
            printf(" Satellite Type = Empty Orbit\n");
            break;
        case Default:
            printf(" Satellite Type = ?\n");
            break;
        }
        }

    return 0;
    }

int StarSystem::naturalSatelliteDetermination(){

    int random = randomDie(100,1);
    switch(this->starClass){
        case 'O':
            if(random <= 45){
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            else if(random <= 54){
                random = randomDie(10, 1);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = random;
                }
            else if(random <= 95){
                random = randomDie(10, 1);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = 0;
                }
            else{
                //Companion Star Add Later
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            break;
        case 'B':
            if(random <= 35){
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            else if(random <= 64){
                random = randomDie(10, 1);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = random;
                }
            else if(random <= 95){
                random = randomDie(10, 1);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = 0;
                }
            else{
                //Companion Star Add Later
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            break;
        case 'A':
            if(random <= 25){
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            else if(random <= 64){
                random = randomDie(10, 1);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = random;
                }
            else if(random <= 95){
                random = randomDie(10, 1);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = 0;
                }
            else{
                //Companion Star Add Later
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            break;
        case 'F':
            if(random <= 20){
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            else if(random <= 80){
                random = randomDie(10, 1);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = random;
                }
            else if(random <= 95){
                random = randomDie(4, 3);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = random;
                }
            else{
                //Companion Star Add Later
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            break;
        case 'G':
            if(random <= 20){
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            else if(random <= 75){
                random = randomDie(10, 1);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = random;
                }
            else if(random <= 95){
                random = randomDie(4, 3);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = random;
                }
            else{
                //Companion Star Add Later
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            break;
        case 'K':
            if(random <= 50){
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            else if(random <= 70){
                random = randomDie(10, 1);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = random;
                }
            else if(random <= 95){
                random = randomDie(4, 3);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = random;
                }
            else{
                //Companion Star Add Later
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            break;
        case 'M':
            if(random <= 75){
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            else if(random <= 95){
                random = randomDie(10, 1);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = random;
                }
            else{
                //Companion Star Add Later
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            break;
        case 'N':
            if(random <= 95){
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            else if(random <= 100){
                random = randomDie(10, 1);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = random;
                }
            else{
                //Companion Star Add Later
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            break;
        case 'S':
            if(random <= 95){
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            else if(random <= 100){
                random = randomDie(10, 1);
                this->naturalSatellites = random;
                this->naturalSatellitesHabitable = 0;
                }
            else{
                //Companion Star Add Later
                this->naturalSatellites = 0;
                this->naturalSatellitesHabitable = 0;
                }
            break;
        case Default:
            this->naturalSatellites = -1;
            this->naturalSatellitesHabitable = -1;
        }

            //this->naturalSatellitesHabitable = 9; // TESTING *REMOVE*

    printf(" *STUB* naturalSatellites = %d\n", this->naturalSatellites);
    printf(" *STUB* naturalSatellitesHabitable = %d\n", this->naturalSatellitesHabitable);

    return 0;
    }

