#include <windows.h>								// Header File For Windows
#include <gl\gl.h>								// Header File For The OpenGL32 Library
#include <gl\glu.h>								// Header File For The GLu32 Library
#include <gl\glaux.h>								// Header File For The GLaux Library
#include "stdafx.h"
#include <stdlib.h>
#include <stdarg.h>
#include <stdio.h>
#include <time.h>
#include "StarSystem.h"
#include <string.h>
#include <math.h>
#include "xyz.h"
#include "BitMapLoader.h"

HGLRC           hRC=NULL;							// Permanent Rendering Context
HDC             hDC=NULL;							// Private GDI Device Context
HWND            hWnd=NULL;							// Holds Our Window Handle
HINSTANCE       hInstance;							// Holds The Instance Of The Application

GLuint	base;							// Base Display List For The Font Set
GLfloat	cnt1;							// 1st Counter Used To Move Text & For Coloring
GLfloat	cnt2;							// 2nd Counter Used To Move Text & For Coloring

bool	keys[256];								// Array Used For The Keyboard Routine
bool	active=TRUE;								// Window Active Flag Set To TRUE By Default
bool	fullscreen=TRUE;							// Fullscreen Flag Set To Fullscreen Mode By Default
bool	light = TRUE;									// Lighting ON / OFF
bool    blend = TRUE;						// Blending OFF/ON? ( NEW )
bool    masking = TRUE;                    // Masking OFF/ON?
bool    orbits = TRUE;                     // Show orbit
bool	lp;									// L Pressed?
bool	fp;									// F Pressed?
bool	bp;						// B Pressed? ( NEW )
bool    mp;
bool    sp;
bool    op;

GLfloat	xrot = 15.0;							// X Rotation
GLfloat	yrot;									// Y Rotation
GLfloat xspeed;									// X Rotation Speed
GLfloat yspeed;									// Y Rotation Speed
GLfloat	z=-5.0f;								// Depth Into The Screen

GLfloat LightAmbient[]= { 0.5f, 0.5f, 0.5f, 1.0f }; 				// Ambient Light Values ( NEW )
GLfloat LightDiffuse[]= { 1.0f, 1.0f, 1.0f, 1.0f };				 // Diffuse Light Values ( NEW )
GLfloat LightPosition[]= { 0.0f, 0.0f, 2.0f, 1.0f };				 // Light Position ( NEW )

GLuint	filter = 2;									// Which Filter To Use

GLuint	suntexture[3];								// Storage for 3 textures
GLuint	planetcloudtexture[3];						// Storage for 3 textures
GLuint  planetcloudmasktexture[3];
GLuint  planetdrytexture[3];
GLuint  planetgastexture[3];
GLuint  planetwettexture[3];
GLuint  planetbarrentexture[3];

StarSystem* star;
int Seed;
int shown = 0;

LRESULT	CALLBACK WndProc(HWND, UINT, WPARAM, LPARAM);				// Declaration For WndProc

int LoadGLTextures()								// Load Bitmaps And Convert To Textures
{
	int Status=FALSE;							// Status Indicator

    BMPLoader *TextureImage = new BMPLoader[5];	// Create Storage Space For The Texture

	// Load The Bitmap, Check For Errors, If Bitmap's Not Found Quit
    if (!TextureImage[0].load("Data/sunmap.bmp"))
	{
		Status=TRUE;							// Set The Status To TRUE
		glGenTextures(3, &suntexture[0]);					// Create Three Textures
		// Create Nearest Filtered Texture
		glBindTexture(GL_TEXTURE_2D, suntexture[0]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_NEAREST); // ( NEW )
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_NEAREST); // ( NEW )
        glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImage[0].getSizeX(), TextureImage[0].getSizeY(), 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImage[0].getBitmapData());
		// Create Linear Filtered Texture
		glBindTexture(GL_TEXTURE_2D, suntexture[1]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
        glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImage[0].getSizeX(), TextureImage[0].getSizeY(), 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImage[0].getBitmapData());
		// Create MipMapped Texture
		glBindTexture(GL_TEXTURE_2D, suntexture[2]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR_MIPMAP_NEAREST); // ( NEW )
        gluBuild2DMipmaps(GL_TEXTURE_2D, 3, TextureImage[0].getSizeX(), TextureImage[0].getSizeY(), GL_RGB, GL_UNSIGNED_BYTE, TextureImage[0].getBitmapData());
	}
    if (!TextureImage[1].load("Data/earthcloudmap.bmp"))
	{
		Status=TRUE;							// Set The Status To TRUE
		glGenTextures(3, &planetcloudtexture[0]);					// Create Three Textures
		// Create Nearest Filtered Texture
		glBindTexture(GL_TEXTURE_2D, planetcloudtexture[0]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_NEAREST); // ( NEW )
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_NEAREST); // ( NEW )
        glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
		// Create Linear Filtered Texture
		glBindTexture(GL_TEXTURE_2D, planetcloudtexture[1]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
        glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
		// Create MipMapped Texture
		glBindTexture(GL_TEXTURE_2D, planetcloudtexture[2]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR_MIPMAP_NEAREST); // ( NEW )
        gluBuild2DMipmaps(GL_TEXTURE_2D, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
	}
    if (!TextureImage[1].load("Data/earthcloudmapmask.bmp"))
	{
		Status=TRUE;							// Set The Status To TRUE
		glGenTextures(3, &planetcloudmasktexture[0]);					// Create Three Textures
		// Create Nearest Filtered Texture
		glBindTexture(GL_TEXTURE_2D, planetcloudmasktexture[0]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_NEAREST); // ( NEW )
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_NEAREST); // ( NEW )
        glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
		// Create Linear Filtered Texture
		glBindTexture(GL_TEXTURE_2D, planetcloudmasktexture[1]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
        glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
		// Create MipMapped Texture
		glBindTexture(GL_TEXTURE_2D, planetcloudmasktexture[2]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR_MIPMAP_NEAREST); // ( NEW )
        gluBuild2DMipmaps(GL_TEXTURE_2D, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
	}

    if (!TextureImage[1].load("Data/earthmap.bmp"))
	{
		Status=TRUE;							// Set The Status To TRUE
		glGenTextures(3, &planetwettexture[0]);					// Create Three Textures
		// Create Nearest Filtered Texture
		glBindTexture(GL_TEXTURE_2D, planetwettexture[0]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_NEAREST); // ( NEW )
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_NEAREST); // ( NEW )
        glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
		// Create Linear Filtered Texture
		glBindTexture(GL_TEXTURE_2D, planetwettexture[1]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
        glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
		// Create MipMapped Texture
		glBindTexture(GL_TEXTURE_2D, planetwettexture[2]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR_MIPMAP_NEAREST); // ( NEW )
        gluBuild2DMipmaps(GL_TEXTURE_2D, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
	}
    if (!TextureImage[1].load("Data/jupitermap.bmp"))
	{
		Status=TRUE;							// Set The Status To TRUE
		glGenTextures(3, &planetgastexture[0]);					// Create Three Textures
		// Create Nearest Filtered Texture
		glBindTexture(GL_TEXTURE_2D, planetgastexture[0]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_NEAREST); // ( NEW )
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_NEAREST); // ( NEW )
        glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
		// Create Linear Filtered Texture
		glBindTexture(GL_TEXTURE_2D, planetgastexture[1]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
        glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
		// Create MipMapped Texture
		glBindTexture(GL_TEXTURE_2D, planetgastexture[2]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR_MIPMAP_NEAREST); // ( NEW )
        gluBuild2DMipmaps(GL_TEXTURE_2D, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
	}
    if (!TextureImage[1].load("Data/venusmap.bmp"))
	{
		Status=TRUE;							// Set The Status To TRUE
		glGenTextures(3, &planetdrytexture[0]);					// Create Three Textures
		// Create Nearest Filtered Texture
		glBindTexture(GL_TEXTURE_2D, planetdrytexture[0]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_NEAREST); // ( NEW )
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_NEAREST); // ( NEW )
        glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
		// Create Linear Filtered Texture
		glBindTexture(GL_TEXTURE_2D, planetdrytexture[1]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);
        glTexImage2D(GL_TEXTURE_2D, 0, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), 0, GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
		// Create MipMapped Texture
		glBindTexture(GL_TEXTURE_2D, planetdrytexture[2]);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);
		glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR_MIPMAP_NEAREST); // ( NEW )
        gluBuild2DMipmaps(GL_TEXTURE_2D, 3, TextureImage[1].getSizeX(), TextureImage[1].getSizeY(), GL_RGB, GL_UNSIGNED_BYTE, TextureImage[1].getBitmapData());
	}
//	if (TextureImage[0].isStored())							// If Texture Exists
//	{
//   	free(TextureImage);						// Free The Image Structure
//	}
	return Status;								// Return The Status
}

GLvoid BuildFont(GLvoid)					// Build Our Bitmap Font
{
	HFONT	font;						// Windows Font ID
	HFONT	oldfont;					// Used For Good House Keeping

	base = glGenLists(96);					// Storage For 96 Characters ( NEW )
	font = CreateFont(	-12,				// Height Of Font ( NEW )24
				0,				// Width Of Font
				0,				// Angle Of Escapement
				0,				// Orientation Angle
				FW_BOLD,			// Font Weight
				FALSE,				// Italic
				FALSE,				// Underline
				FALSE,				// Strikeout
				ANSI_CHARSET,			// Character Set Identifier
				OUT_TT_PRECIS,			// Output Precision
				CLIP_DEFAULT_PRECIS,		// Clipping Precision
				ANTIALIASED_QUALITY,		// Output Quality
				FF_DONTCARE|DEFAULT_PITCH,	// Family And Pitch
				"Courier New");			// Font Name
	oldfont = (HFONT)SelectObject(hDC, font);		// Selects The Font We Want
	wglUseFontBitmaps(hDC, 32, 96, base);			// Builds 96 Characters Starting At Character 32
	SelectObject(hDC, oldfont);				// Selects The Font We Want
	DeleteObject(font);					// Delete The Font
}

GLvoid KillFont(GLvoid)						// Delete The Font List
{
 	glDeleteLists(base, 96);				// Delete All 96 Characters ( NEW )
}

GLvoid glPrint(const char *fmt, ...)				// Custom GL "Print" Routine
{
	char		text[256];				// Holds Our String
	va_list		ap;					// Pointer To List Of Arguments
	if (fmt == NULL)					// If There's No Text
		return;						// Do Nothing
	va_start(ap, fmt);					// Parses The String For Variables
	    vsprintf(text, fmt, ap);				// And Converts Symbols To Actual Numbers
	va_end(ap);						// Results Are Stored In Text
	glPushAttrib(GL_LIST_BIT);				// Pushes The Display List Bits		( NEW )
	glListBase(base - 32);					// Sets The Base Character to 32	( NEW )
	glCallLists(strlen(text), GL_UNSIGNED_BYTE, text);	// Draws The Display List Text	( NEW )
	glPopAttrib();						// Pops The Display List Bits	( NEW )
}

Planet::printPlanetGL(double x, double y, double yVar){
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*0);
    glPrint("**Planet Info Dump**");
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*1);
    glPrint("   Planet Number = %d\n", planetNumber);
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*2);
    glPrint("   Orbital Radius = %f\n", orbitalRadius);
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*3);
    glPrint("   Orbital Speed = %f\n", orbitalSpeed);
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*4);
    glPrint("   Rotational Speed = %f\n", rotationalSpeed);
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*5);
    switch(type){
        case Rock:
            glPrint("   Satellite Type = Rock Planet\n");
            break;
        case Gas:
            glPrint("   Satellite Type = Gas Giant\n");
            break;
        case Asteroid:
            glPrint("   Satellite Type = Asteroid Field\n");
            break;
        case Empty:
            glPrint("   Satellite Type = Empty Orbit\n");
            break;
        case Default:
            glPrint("   Satellite Type = ?\n");
            break;
        }
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*6);
    glPrint("   Circumference = %.2f x 10^%d\n", baseCirc, circExponent);
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*7);
    glPrint("   Density = %.2f\n", density);
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*8);
    glPrint("   Base Gravity = %.2f\n", baseGravity);
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*9);
    glPrint("   Escape Velocity = %f KPS\n", baseGravity * 11);
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*10);
    if( inStellarEcosphere == 1 )
        glPrint("   This planet is in the stellar ecosphere\n");
    //glPrint("   Atmosphere Level = %d\n", paramAtmos);
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*11);
    switch(paramAtmos){
        case 1:
            glPrint("   Atmosphere is presently escaping the planet\n");
            break;
        case 2:
            glPrint("   Plethora of toxic trace metals and gases in atmosphere\n");
            break;
        case 3:
            glPrint("   Exceedingly thin atmosphere\n");
            break;
        case 4:
            glPrint("   Predominantly chlorine\n");
            break;
        case 5:
            glPrint("   Mainly ammonia and methane\n");
            break;
        case 6:
            glPrint("   Predominantly carbon dioxide\n");
            break;
        case 7:
            glPrint("   Oxygen/Nitrogen/Carbon dioxide and contaminants\n");
            break;
        case 8:
            glPrint("   Oxygen/Nitrogen with few contaminants\n");
            break;
        case 9:
            glPrint("   Oxygen/Nitrogen with significant ozone component in stratosphere\n");
            break;
        case 10:
            glPrint("   A thick atmosphere which is predominantly oxygen and nitrogen\n");
            break;
        case 0:
            glPrint("   No Atmosphere\n");
            break;
        }
    //glPrint("   Hydrosphere Level = %d\n", paramHydro);
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*12);
    switch(paramHydro){
        case 1:
            glPrint("   No standing water\n");
            break;
        case 2:
            glPrint("   World is predominantly desert\n");
            break;
        case 3:
            glPrint("   Arid\n");
            break;
        case 4:
            glPrint("   Semi-arid\n");
            break;
        case 5:
            glPrint("   Balanced\n");
            break;
        case 6:
            glPrint("   Ocean World\n");
            break;
        case 7:
            glPrint("   Water vapor is major component of atmosphere\n");
            break;
        case 8:
            glPrint("   Water vapor is major component of atmosphere\n");
            break;
        case 9:
            glPrint("   Water vapor is major component of atmosphere\n");
            break;
        case 10:
            glPrint("   Water vapor is major component of atmosphere\n");
            break;
        case 0:
            glPrint("   No water\n");
            break;
        }
    //glPrint("   Climate Level = %d\n", paramClima);
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*13);
    switch(paramClima){
        case 1:
            glPrint("   This place is an iceball\n");
            break;
        case 2:
            glPrint("   Arctic climate prevails\n");
            break;
        case 3:
            glPrint("   A cool temperate mix\n");
            break;
        case 4:
            glPrint("   Temperate mix\n");
            break;
        case 5:
            glPrint("   A warm temperate mix\n");
            break;
        case 6:
            glPrint("   Hot\n");
            break;
        case 7:
            glPrint("   Greenhouse Inferno\n");
            break;
        case 8:
            glPrint("   Variable due to an eccentric orbit\n");
            break;
        case 9:
            glPrint("   Variable due to an unusual rotation period\n");
            break;
        case 10:
            glPrint("   Hellish\n");
            break;
        case 0:
            glPrint("   No climate\n");
            break;
        }
    //glPrint("   Biosphere Level = %d\n", paramBiosp);
    glRasterPos2d(-0.50f*x, 0.35f*y+yVar*14);
    switch(paramBiosp){
        case 1:
            glPrint("   Biotoxins in atmosphere. They are so exotic as to be normally undetected.\n");
            break;
        case 2:
            glPrint("   Biotoxins in the atmosphere\n");
            break;
        case 3:
            glPrint("   No life\n");
            break;
        case 4:
            glPrint("   No life\n");
            break;
        case 5:
            glPrint("   No life\n");
            break;
        case 6:
            glPrint("   Proto-organisms\n");
            break;
        case 7:
            glPrint("   Proto-organisms and plant-like life\n");
            break;
        case 8:
            glPrint("   Non-sentient lower life forms\n");
            break;
        case 9:
            glPrint("   Sentient beings present. Developmental stage should be chosen/generated.\n");
            break;
        case 10:
            glPrint("   Highly evolved or unusual life form\n");
            break;
        case 0:
            glPrint("   No life\n");
            break;
        }


    return 0;
}

int StarSystem::printStarGL(double x, double y, double yVar)    {
    if(shown == 0){
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*0);
        glPrint("**Star Info Dump**\n");
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*1);
        glPrint("   key = %d\n", key);
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*2);
        glPrint("   Star Class = %c\n", starClass);
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*3);
        glPrint("   Stellar Type = %d\n", stellarType);
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*4);
        glPrint("   Brightness = %d\n", brightness);
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*5);
        glPrint("   Brightness Vs Sol = %.6f\n", brightnessVsSol);
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*6);
        glPrint("   Radius Vs Sol = %.4f\n", radiusVsSol);
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*7);
        glPrint("   Mass Vs Sol = %f\n", massVsSol);
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*8);
        glPrint("   Gravity Well = %.3fAU or %.0f million kilometers\n", gravityWell, (gravityWell*150));
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*9);
        glPrint("   Star Description: %s\n", starDesc);
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*10);
        glPrint("   Natural Sattelites = %d\n", naturalSatellites);
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*11);
        glPrint("   Habitable Natural Sattelites = %d\n", naturalSatellitesHabitable);
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*12);
        glPrint("   Planets in Stellar Ecosphere = %d\n", planetsInEcosphere);
        glRasterPos2d(-0.50f*x, 0.35f*y+yVar*13);
        } else if(shown <= (naturalSatellites) && shown > 0){
            planet[shown-1].printPlanetGL(x,y,yVar);
            }
    return 0;
}

/*
   Create a sphere centered at c, with radius r, and precision n
   Draw a point for zero radius spheres
*/
void CreateSphere(XYZ c,double r,int n)
{
   int i,j;
   double theta1,theta2,theta3;
   XYZ e,p;

   if (r < 0)
      r = -r;
   if (n < 0)
      n = -n;
   if (n < 4 || r <= 0) {
      glBegin(GL_POINTS);
      glVertex3d(c.x,c.y,c.z);
      glEnd();
      return;
   }

   for (j=0;j<n/2;j++) {
      theta1 = j * TWOPI / n - PID2;
      theta2 = (j + 1) * TWOPI / n - PID2;

      glBegin(GL_QUAD_STRIP);
      for (i=0;i<=n;i++) {
         theta3 = i * TWOPI / n;

         e.x = cos(theta2) * cos(theta3);
         e.y = sin(theta2);
         e.z = cos(theta2) * sin(theta3);
         p.x = c.x + r * e.x;
         p.y = c.y + r * e.y;
         p.z = c.z + r * e.z;

         glNormal3d(e.x,e.y,e.z);
         glTexCoord2d(i/(double)n,2*(j+1)/(double)n);
         glVertex3d(p.x,p.y,p.z);

         e.x = cos(theta1) * cos(theta3);
         e.y = sin(theta1);
         e.z = cos(theta1) * sin(theta3);
         p.x = c.x + r * e.x;
         p.y = c.y + r * e.y;
         p.z = c.z + r * e.z;

         glNormal3d(e.x,e.y,e.z);
         glTexCoord2d(i/(double)n,2*j/(double)n);
         glVertex3d(p.x,p.y,p.z);
      }
      glEnd();
   }
}

GLvoid ReSizeGLScene(GLsizei width, GLsizei height)				// Resize And Initialize The GL Window
{
    if (height==0)								// Prevent A Divide By Zero By
	{
		height=1;							// Making Height Equal One
	}

	glViewport(0, 0, width, height);					// Reset The Current Viewport
	glMatrixMode(GL_PROJECTION);						// Select The Projection Matrix
	glLoadIdentity();							// Reset The Projection Matrix

	// Calculate The Aspect Ratio Of The Window
	gluPerspective(45.0f,(GLfloat)width/(GLfloat)height,0.1f,100.0f);

	glMatrixMode(GL_MODELVIEW);						// Select The Modelview Matrix
	glLoadIdentity();							// Reset The Modelview Matrix

}

int InitGL(GLvoid)								// All Setup For OpenGL Goes Here
{
	if (!LoadGLTextures())							// Jump To Texture Loading Routine
	{
		return FALSE;							// If Texture Didn't Load Return FALSE
	}

	glEnable(GL_TEXTURE_2D);						// Enable Texture Mapping
	glShadeModel(GL_SMOOTH);						// Enable Smooth Shading
	glClearColor(0.0f, 0.0f, 0.0f, 0.0f);					// Black Background
	glClearDepth(1.0f);							// Depth Buffer Setup
	glEnable(GL_DEPTH_TEST);						// Enables Depth Testing
	glDepthFunc(GL_LEQUAL);							// The Type Of Depth Testing To Do
	glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_NICEST);			// Really Nice Perspective Calculations
	glLightfv(GL_LIGHT1, GL_AMBIENT, LightAmbient);				// Setup The Ambient Light
	glLightfv(GL_LIGHT1, GL_DIFFUSE, LightDiffuse);				// Setup The Diffuse Light
	glLightfv(GL_LIGHT1, GL_POSITION,LightPosition);			// Position The Light
	glEnable(GL_LIGHT1);							// Enable Light One
	glEnable(GL_COLOR_MATERIAL);						// Enable Material Coloring
	BuildFont();						// Build The Font

	return TRUE;						// Initialization Went OK
}

/** Draws the sun. The radius of Sol is 431852 miles. 
 *  The size of the sun is between 1/100th - 1000x Sol.
 *                                 4318.52-431852000 miles.
 *
 **/
int DrawSun(double size)
{
    XYZ sun;
    sun.x = 0.0;
    sun.y = 0.0;
    sun.z = 0.0;
	glBlendFunc(GL_SRC_ALPHA,GL_ONE);		// Blending Function For Translucency Based On Source Alpha Value ( NEW )
    switch(star->starDescNumberGet()){
        case 0:
            glColor4f(0.89f,0.89f,0.97f,0.9f);  // Extremely bright blue-white
            break;
        case 1:
            glColor4f(0.79f,0.81f,0.97f,0.9f);  // Very bright blue-white
            break;
        case 2:
            glColor4f(0.59f,0.64f,0.97f,0.9f);  // Blue-white
            break;
        case 3:
            glColor4f(0.90f,0.88f,0.97f,0.9f);  // Bluish white
            break;
        case 4:
            glColor4f(0.97f,0.97f,0.97f,0.9f);  // White
            break;
        case 5:
            glColor4f(0.97f,0.97f,0.83f,0.9f);  // Yellowish white
            break;
        case 6:
            glColor4f(0.97f,0.97f,0.74f,0.9f);  // Whitish yellow
            break;
        case 7:
            glColor4f(0.97f,0.97f,0.00f,0.9f);  // Yellow
            break;
        case 8:
            glColor4f(0.97f,0.82f,0.27f,0.9f);  // Orangish yellow
            break;
        case 9:
            glColor4f(0.97f,0.69f,0.00f,0.9f);  // Yellowish orange
            break;
        case 10:
            glColor4f(1.00f,0.60f,0.00f,0.9f);  // Orange
            break;
        case 11:
            glColor4f(1.00f,0.40f,0.00f,0.9f);  // Reddish orange
            break;
        case 12:
            glColor4f(1.00f,0.40f,0.00f,0.9f);  // Orangish red
            break;
        case 13:
            glColor4f(1.00f,0.00f,0.00f,0.9f);  // Bright red
            break;
        case 14:
            glColor4f(0.80f,0.00f,0.00f,0.9f);  // Deep red
            break;
        case 15:
            glColor4f(0.60f,0.00f,0.00f,0.9f);  // Dull red
            break;
        case 16:
            glColor4f(0.40f,0.00f,0.00f,0.9f);  // Dim red
            break;
//        case Default:
//            glColor4f(0.80f,0.14f,0.54f,0.9f);  // Bright Pink            
//            break;
        }
    glBindTexture(GL_TEXTURE_2D, suntexture[filter]);				// Select A Texture Based On filter
    //glColor4f(1.0f,1.0f,0.6f,0.9f);
//    CreateSphere(sun, 0.97 * (size * SOL - sunMin) / (sunMax - sunMin) +1 , 100);
    //glColor4f(1.0f,1.0f,0.75f,1.0f);

    CreateSphere(sun, 1.0 * (size * SOL - sunMin) / (sunMax - sunMin) +1 , 100);
    return true;
}
/** Draws a planet. The radius of the Earth is 3963 miles.
 *  The planet circumference is between 1*10^3 - 9x10^5 miles
 *  The planet radius is then between 1.6*10^2 - 1.4x10^5 miles
 *                                    1,600 - 140,000 miles
 *  The Orbital Radius of the first planet is between 4/100 AU - 40 AU.
 *                                                    3,729,000 - 3,729,000,000 miles.
 *                                                    1 AU = 93,225,000 miles
 **/
int DrawPlanet(int number)
    {
    double size = (star->planet[number].baseCirc);
    size = (size * pow(10,(star->planet[number].circExponent))) / TWOPI;
    XYZ planet;
    planet.x = 0.0;
    planet.y = 0.0;
    planet.z = 0.0;
    switch(star->planet[number].type){          //Asteroid, Rock, Gas, Empty, Default 
        case Rock:
            glBindTexture(GL_TEXTURE_2D, planetdrytexture[filter]);				// Select A Texture Based On filter
            glColor4f(0.71f,0.43f,0.11f,1.0f);      // brownish
            CreateSphere(planet, 0.97 * (size - planetMin) / (planetMax - planetMin) + 0.15 , 100); 
            if(star->planet[number].paramAtmos > 0)
                {
                if(masking)
                    {
                    glEnable(GL_BLEND);		// Turn Blending On
                    //glDisable(GL_DEPTH_TEST);	// Turn Depth Testing Off
                    glBlendFunc(GL_DST_COLOR,GL_ZERO);
                    glColor4f(1.00f,1.00f,1.00f,1.0f);      // white
                    glBindTexture(GL_TEXTURE_2D, planetcloudmasktexture[filter]);				// Select A Texture Based On filter
                    CreateSphere(planet, 1.2 * (size - planetMin) / (planetMax - planetMin) + 0.15 , 100); 
                    switch(star->planet[number].paramAtmos){
                        case 1:
                            glColor4f(0.9f,0.9f,0.98f,1.0f);
                            break;
                        case 2:
                            glColor4f(0.78f,0.36f,0.18f,1.0f);
                            break;
                        case 3:
                            glColor4f(0.9f,0.93f,0.98f,1.0f);
                            break;
                        case 4:
                            glColor4f(0.30f,0.85f,0.23f,1.0f);
                            break;
                        case 5:
                            glColor4f(0.9f,0.9f,0.98f,1.0f);
                            break;
                        default:
                            glColor4f(0.9f,0.9f,0.98f,1.0f);
                            break;
                        }

                    glBlendFunc(GL_ONE, GL_ONE);
                    glBindTexture(GL_TEXTURE_2D, planetcloudtexture[filter]);				// Select A Texture Based On filter
                    //glColor4f(0.2f,0.9f,0.2f,1.0f);      // white
                    CreateSphere(planet, 1.2 * (size - planetMin) / (planetMax - planetMin) + 0.15 , 100); 
			        glDisable(GL_BLEND);		// Turn Blending Off
			        glEnable(GL_DEPTH_TEST);	// Turn Depth Testing On
                    }
                }
            break;
        case Gas:
            glBindTexture(GL_TEXTURE_2D, planetgastexture[filter]);				// Select A Texture Based On filter
            glColor4f(0.94f,0.75f,0.52f,0.9f);    // tan
            CreateSphere(planet, 0.97 * (size - planetMin) / (planetMax - planetMin) + 0.15 , 100); 
            break;
        case Asteroid:
            glBindTexture(GL_TEXTURE_2D, planetdrytexture[filter]);				// Select A Texture Based On filter
            glColor4f(1.00f,0.00f,1.00f,0.9f);    // Pink
            CreateSphere(planet, 0.97 * (size - planetMin) / (planetMax - planetMin) + 0.15 , 100); 
            break;
        case Empty:
            glColor4f(0.00f,0.00f,0.00f,0.9f);    // Black
            break;
        case Default:
            glColor4f(0.00f,0.00f,1.0f,0.9f);    // Blue
            CreateSphere(planet, 0.97 * (size - planetMin) / (planetMax - planetMin) + 0.15 , 100); 
            break;
        }

    return true;
    }

int DrawOrbit(int radius)
    {
        glColor4f(1.00f,0.00f,1.0f,1.0f);    // Pink
        glLineWidth((float)0.3);
        glBegin (GL_LINE_STRIP);
        for(double i=0; i<8; i+=.1)
            {
            glVertex3d(sin(i) * (double)radius, 0.0, cos(i) * (double)radius );
            }
        glEnd ();
    return true;
    }


int DrawGLScene(GLvoid)								// Here's Where We Do All The Drawing
{
    if (!light)				// If Not Light
	{
		glDisable(GL_LIGHTING);		// Disable Lighting
	}
	else					// Otherwise
	{
		glEnable(GL_LIGHTING);		// Enable Lighting
	}

	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);			// Clear The Screen And The Depth Buffer
	glLoadIdentity();							// Reset The View
    glTranslatef(0.0f,0.0f,-1.0f);
    glColor3f(1.0f,1.0f,1.0f);
    star->printStarGL(1.0, 1.0, -.02);

    glRasterPos2f(0.20f, -0.40f);
    glPrint("%f, %f, %f", xrot, yrot, z);
	glTranslatef(0.0f,0.0f,z);				// Move One Unit Into The Screen
    glRotatef(xrot,1.0f,0.0f,0.0f);						// Rotate On The X Axis By xrot
	//glRotatef(yrot,0.0f,1.0f,0.0f);						// Rotate On The Y Axis By yrot
    glRotated(yrot * 10.0, 0.0f, 1.0f, 0.0f);

    DrawSun(star->radiusVsSolGet());
    glRotated(yrot * 10.0, 0.0f, -1.0f, 0.0f);
    for(int i = 0; i < star->naturalSatellitesGet(); i++)
    {
        // Draw orbit line
        if(orbits)
        {
            if((star->planet[i].type == Gas) || (star->planet[i].type == Rock))
                DrawOrbit((i+1)*3.0f);
        }
        glRotated(yrot * star->planet[i].orbitalSpeed, 0.0f, 1.0f, 0.0f);
        glTranslatef(((i+1)*3.0f),0.0f,0.0f);
        glRotated(yrot * star->planet[i].orbitalSpeed, 0.0f, -1.0f, 0.0f);
        if((shown == i+1) && ((star->planet[i].type == Gas) || (star->planet[i].type == Rock))) // Highlight the selected planet with a halo
        {
        glColor4f(1.00f,0.00f,1.0f,1.0f);    // Pink
        glLineWidth(2.0);
        glBegin (GL_LINE_LOOP);
            glVertex2d(-0.7, -0.7);
            glVertex2d(-0.7, 0.7);
            glVertex2d(0.7, 0.7);
            glVertex2d(0.7,-0.7);

        glEnd ();
        }

        glRotated(yrot * star->planet[i].orbitalSpeed, 0.0f, 1.0f, 0.0f);
        glRotated(yrot * star->planet[i].rotationalSpeed, 0.0f, 1.0f, 0.0f);
        DrawPlanet(i);
        glRotated(yrot * star->planet[i].rotationalSpeed, 0.0f, -1.0f, 0.0f);
        glTranslatef(-((i+1)*3.0f),0.0f,0.0f);
        glRotated(yrot * star->planet[i].orbitalSpeed, 0.0f, -1.0f, 0.0f);
    }
    glColor4f(1.0f,1.0f,1.0f,0.2f);
	glTranslatef(0.0f,0.0f,4);				// Move One Unit Into The Screen
	/**	if (!masking)							// Is Masking On?
		{
	        glBlendFunc(GL_DST_COLOR,GL_ZERO);	
			glBindTexture(GL_TEXTURE_2D, planetcloudmasktexture[filter]);		// Select The Second Mask Texture
			glBegin(GL_QUADS);					// Start Drawing A Textured Quad
				glTexCoord2f(0.0f, 0.0f); glVertex3f(-1.1f, -1.1f,  0.0f);	// Bottom Left
				glTexCoord2f(1.0f, 0.0f); glVertex3f( 1.1f, -1.1f,  0.0f);	// Bottom Right
				glTexCoord2f(1.0f, 1.0f); glVertex3f( 1.1f,  1.1f,  0.0f);	// Top Right
				glTexCoord2f(0.0f, 1.0f); glVertex3f(-1.1f,  1.1f,  0.0f);	// Top Left
			glEnd();						// Done Drawing The Quad
        glColor4f(1.00f,0.00f,1.0f,0.0f);    // Pink
		
		glBlendFunc(GL_ONE, GL_ONE);					// Copy Image 2 Color To The Screen
		glBindTexture(GL_TEXTURE_2D, planetcloudtexture[filter]);			// Select The Second Image Texture
		glBegin(GL_QUADS);						// Start Drawing A Textured Quad
			glTexCoord2f(0.0f, 0.0f); glVertex3f(-1.1f, -1.1f,  0.0f);	// Bottom Left
			glTexCoord2f(1.0f, 0.0f); glVertex3f( 1.1f, -1.1f,  0.0f);	// Bottom Right
			glTexCoord2f(1.0f, 1.0f); glVertex3f( 1.1f,  1.1f,  0.0f);	// Top Right
			glTexCoord2f(0.0f, 1.0f); glVertex3f(-1.1f,  1.1f,  0.0f);	// Top Left
		glEnd();							// Done Drawing The Quad
    	}**/


    // Translate the view to the current planet or star
    if((shown < 1) || (shown > star->naturalSatellitesGet()))
        {
        glRasterPos2f(0.20f, -0.40f);
        glPrint("%i", shown);
        }
    else {
        glRasterPos2f(0.20f, -0.40f);
        glPrint("%i", shown);
        }




	xrot+=xspeed;								// Add xspeed To xrot
	yrot+=yspeed;								// Add yspeed To yrot
	return TRUE;								// Keep Going
}

GLvoid KillGLWindow(GLvoid)							// Properly Kill The Window
{
	if (fullscreen)								// Are We In Fullscreen Mode?
	{
		ChangeDisplaySettings(NULL,0);					// If So Switch Back To The Desktop
		ShowCursor(TRUE);						// Show Mouse Pointer
	}
	if (hRC)								// Do We Have A Rendering Context?
	{
		if (!wglMakeCurrent(NULL,NULL))					// Are We Able To Release The DC And RC Contexts?
		{
			MessageBox(NULL,"Release Of DC And RC Failed.","SHUTDOWN ERROR",MB_OK | MB_ICONINFORMATION);
		}
		if (!wglDeleteContext(hRC))					// Are We Able To Delete The RC?
		{
			MessageBox(NULL,"Release Rendering Context Failed.","SHUTDOWN ERROR",MB_OK | MB_ICONINFORMATION);
		}
		hRC=NULL;							// Set RC To NULL
	}
	if (hDC && !ReleaseDC(hWnd,hDC))					// Are We Able To Release The DC
	{
		MessageBox(NULL,"Release Device Context Failed.","SHUTDOWN ERROR",MB_OK | MB_ICONINFORMATION);
		hDC=NULL;							// Set DC To NULL
	}
	if (hWnd && !DestroyWindow(hWnd))					// Are We Able To Destroy The Window?
	{
		MessageBox(NULL,"Could Not Release hWnd.","SHUTDOWN ERROR",MB_OK | MB_ICONINFORMATION);
		hWnd=NULL;							// Set hWnd To NULL
	}
	if (!UnregisterClass("OpenGL",hInstance))				// Are We Able To Unregister Class
	{
		MessageBox(NULL,"Could Not Unregister Class.","SHUTDOWN ERROR",MB_OK | MB_ICONINFORMATION);
		hInstance=NULL;							// Set hInstance To NULL
	}
	KillFont();						// Destroy The Font
}

BOOL CreateGLWindow(char* title, int width, int height, int bits, bool fullscreenflag)
{
	GLuint		PixelFormat;						// Holds The Results After Searching For A Match
	WNDCLASS	wc;							// Windows Class Structure
	DWORD		dwExStyle;						// Window Extended Style
	DWORD		dwStyle;						// Window Style
	RECT WindowRect;							// Grabs Rectangle Upper Left / Lower Right Values
	WindowRect.left=(long)0;						// Set Left Value To 0
	WindowRect.right=(long)width;						// Set Right Value To Requested Width
	WindowRect.top=(long)0;							// Set Top Value To 0
	WindowRect.bottom=(long)height;						// Set Bottom Value To Requested Height
	fullscreen=fullscreenflag;						// Set The Global Fullscreen Flag
	hInstance		= GetModuleHandle(NULL);			// Grab An Instance For Our Window
	wc.style		= CS_HREDRAW | CS_VREDRAW | CS_OWNDC;		// Redraw On Move, And Own DC For Window
	wc.lpfnWndProc		= (WNDPROC) WndProc;				// WndProc Handles Messages
	wc.cbClsExtra		= 0;						// No Extra Window Data
	wc.cbWndExtra		= 0;						// No Extra Window Data
	wc.hInstance		= hInstance;					// Set The Instance
	wc.hIcon		= LoadIcon(NULL, IDI_WINLOGO);			// Load The Default Icon
	wc.hCursor		= LoadCursor(NULL, IDC_ARROW);			// Load The Arrow Pointer
	wc.hbrBackground	= NULL;						// No Background Required For GL
	wc.lpszMenuName		= NULL;						// We Don't Want A Menu
	wc.lpszClassName	= "OpenGL";					// Set The Class Name

	if (!RegisterClass(&wc))						// Attempt To Register The Window Class
	{
		MessageBox(NULL,"Failed To Register The Window Class.","ERROR",MB_OK|MB_ICONEXCLAMATION);
		return FALSE;							// Exit And Return FALSE
	}

	if (fullscreen)								// Attempt Fullscreen Mode?
	{

		DEVMODE dmScreenSettings;					// Device Mode
		memset(&dmScreenSettings,0,sizeof(dmScreenSettings));		// Makes Sure Memory's Cleared
		dmScreenSettings.dmSize=sizeof(dmScreenSettings);		// Size Of The Devmode Structure
		dmScreenSettings.dmPelsWidth	= width;			// Selected Screen Width
		dmScreenSettings.dmPelsHeight	= height;			// Selected Screen Height
		dmScreenSettings.dmBitsPerPel	= bits;				// Selected Bits Per Pixel
		dmScreenSettings.dmFields=DM_BITSPERPEL|DM_PELSWIDTH|DM_PELSHEIGHT;
		// Try To Set Selected Mode And Get Results.  NOTE: CDS_FULLSCREEN Gets Rid Of Start Bar.
		if (ChangeDisplaySettings(&dmScreenSettings,CDS_FULLSCREEN)!=DISP_CHANGE_SUCCESSFUL)
		{
			// If The Mode Fails, Offer Two Options.  Quit Or Run In A Window.
			if (MessageBox(NULL,"The Requested Fullscreen Mode Is Not Supported By\nYour Video Card. Use Windowed Mode Instead?","NeHe GL",MB_YESNO|MB_ICONEXCLAMATION)==IDYES)
			{
				fullscreen=FALSE;				// Select Windowed Mode (Fullscreen=FALSE)
			}
			else
			{
				// Pop Up A Message Box Letting User Know The Program Is Closing.
				MessageBox(NULL,"Program Will Now Close.","ERROR",MB_OK|MB_ICONSTOP);
				return FALSE;					// Exit And Return FALSE
			}
		}
	}
	if (fullscreen)								// Are We Still In Fullscreen Mode?
	{
		dwExStyle=WS_EX_APPWINDOW;					// Window Extended Style
		dwStyle=WS_POPUP;						// Windows Style
		ShowCursor(FALSE);						// Hide Mouse Pointer
	}
	else
	{
		dwExStyle=WS_EX_APPWINDOW | WS_EX_WINDOWEDGE;			// Window Extended Style
		dwStyle=WS_OVERLAPPEDWINDOW;					// Windows Style
	}
	AdjustWindowRectEx(&WindowRect, dwStyle, FALSE, dwExStyle);		// Adjust Window To True Requested Size

	if (!(hWnd=CreateWindowEx(	dwExStyle,				// Extended Style For The Window
					"OpenGL",				// Class Name
					title,					// Window Title
					WS_CLIPSIBLINGS |			// Required Window Style
					WS_CLIPCHILDREN |			// Required Window Style
					dwStyle,				// Selected Window Style
					0, 0,					// Window Position
					WindowRect.right-WindowRect.left,	// Calculate Adjusted Window Width
					WindowRect.bottom-WindowRect.top,	// Calculate Adjusted Window Height
					NULL,					// No Parent Window
					NULL,					// No Menu
					hInstance,				// Instance
					NULL)))					// Don't Pass Anything To WM_CREATE
	{
		KillGLWindow();							// Reset The Display
		MessageBox(NULL,"Window Creation Error.","ERROR",MB_OK|MB_ICONEXCLAMATION);
		return FALSE;							// Return FALSE
	}
	static	PIXELFORMATDESCRIPTOR pfd=					// pfd Tells Windows How We Want Things To Be
	{
		sizeof(PIXELFORMATDESCRIPTOR),					// Size Of This Pixel Format Descriptor
		1,								// Version Number
		PFD_DRAW_TO_WINDOW |						// Format Must Support Window
		PFD_SUPPORT_OPENGL |						// Format Must Support OpenGL
		PFD_DOUBLEBUFFER,						// Must Support Double Buffering
		PFD_TYPE_RGBA,							// Request An RGBA Format
		bits,								// Select Our Color Depth
		0, 0, 0, 0, 0, 0,						// Color Bits Ignored
		0,								// No Alpha Buffer
		0,								// Shift Bit Ignored
		0,								// No Accumulation Buffer
		0, 0, 0, 0,							// Accumulation Bits Ignored
		16,								// 16Bit Z-Buffer (Depth Buffer)
		0,								// No Stencil Buffer
		0,								// No Auxiliary Buffer
		PFD_MAIN_PLANE,							// Main Drawing Layer
		0,								// Reserved
		0, 0, 0								// Layer Masks Ignored
	};

	if (!(hDC=GetDC(hWnd)))							// Did We Get A Device Context?
	{
		KillGLWindow();							// Reset The Display
		MessageBox(NULL,"Can't Create A GL Device Context.","ERROR",MB_OK|MB_ICONEXCLAMATION);
		return FALSE;							// Return FALSE
	}

    if (!(PixelFormat=ChoosePixelFormat(hDC,&pfd)))				// Did Windows Find A Matching Pixel Format?
	{
		KillGLWindow();							// Reset The Display
		MessageBox(NULL,"Can't Find A Suitable PixelFormat.","ERROR",MB_OK|MB_ICONEXCLAMATION);
		return FALSE;							// Return FALSE
	}

	if(!SetPixelFormat(hDC,PixelFormat,&pfd))				// Are We Able To Set The Pixel Format?
	{
		KillGLWindow();							// Reset The Display
		MessageBox(NULL,"Can't Set The PixelFormat.","ERROR",MB_OK|MB_ICONEXCLAMATION);
		return FALSE;							// Return FALSE
	}

	if (!(hRC=wglCreateContext(hDC)))					// Are We Able To Get A Rendering Context?
	{
		KillGLWindow();							// Reset The Display
		MessageBox(NULL,"Can't Create A GL Rendering Context.","ERROR",MB_OK|MB_ICONEXCLAMATION);
		return FALSE;							// Return FALSE
	}

	if(!wglMakeCurrent(hDC,hRC))						// Try To Activate The Rendering Context
	{
		KillGLWindow();							// Reset The Display
		MessageBox(NULL,"Can't Activate The GL Rendering Context.","ERROR",MB_OK|MB_ICONEXCLAMATION);
		return FALSE;							// Return FALSE
	}

	ShowWindow(hWnd,SW_SHOW);						// Show The Window
	SetForegroundWindow(hWnd);						// Slightly Higher Priority
	SetFocus(hWnd);								// Sets Keyboard Focus To The Window
	ReSizeGLScene(width, height);						// Set Up Our Perspective GL Screen
	if (!InitGL())								// Initialize Our Newly Created GL Window
	{
		KillGLWindow();							// Reset The Display
		MessageBox(NULL,"Initialization Failed.","ERROR",MB_OK|MB_ICONEXCLAMATION);
		return FALSE;							// Return FALSE
	}
	return TRUE;								// Success
}

LRESULT CALLBACK WndProc(	HWND	hWnd,					// Handle For This Window
				UINT	uMsg,					// Message For This Window
				WPARAM	wParam,					// Additional Message Information
				LPARAM	lParam)					// Additional Message Information
{
	switch (uMsg)								// Check For Windows Messages
	{
		case WM_ERASEBKGND:								// Check To See If Windows Is Trying To Erase The Background
			return 0;								// Return 0 (Prevents Flickering While Resizing A Window)
		case WM_ACTIVATE:						// Watch For Window Activate Message
		{
			if (!HIWORD(wParam))					// Check Minimization State
			{
				active=TRUE;					// Program Is Active
			}
			else
			{
				active=FALSE;					// Program Is No Longer Active
			}

			return 0;						// Return To The Message Loop
		}
		case WM_SYSCOMMAND:						// Intercept System Commands
		{
			switch (wParam)						// Check System Calls
			{
				case SC_SCREENSAVE:				// Screensaver Trying To Start?
				case SC_MONITORPOWER:				// Monitor Trying To Enter Powersave?
				return 0;					// Prevent From Happening
			}
			break;							// Exit
		}
		case WM_CLOSE:							// Did We Receive A Close Message?
		{
			PostQuitMessage(0);					// Send A Quit Message
			return 0;						// Jump Back
		}
		case WM_KEYDOWN:						// Is A Key Being Held Down?
		{
			keys[wParam] = TRUE;					// If So, Mark It As TRUE
			return 0;						// Jump Back
		}
		case WM_KEYUP:							// Has A Key Been Released?
		{
			keys[wParam] = FALSE;					// If So, Mark It As FALSE
			return 0;						// Jump Back
		}
		case WM_SIZE:							// Resize The OpenGL Window
		{
			ReSizeGLScene(LOWORD(lParam),HIWORD(lParam));		// LoWord=Width, HiWord=Height
			return 0;						// Jump Back
		}
	}
	// Pass All Unhandled Messages To DefWindowProc
	return DefWindowProc(hWnd,uMsg,wParam,lParam);
}

int WINAPI WinMain(	HINSTANCE	hInstance,				// Instance
			HINSTANCE	hPrevInstance,				// Previous Instance
			LPSTR		lpCmdLine,				// Command Line Parameters
			int		nCmdShow)				// Window Show State
{

	MSG	msg;								// Windows Message Structure
	BOOL	done=FALSE;							// Bool Variable To Exit Loop

    /** Initialize the Star System **/
    star = new StarSystem;
    //star = (StarSystem*) malloc (sizeof(StarSystem*));

//	if(argc > 1) {
//		printf( "   %d\n", argc );
//		Seed = atoi(argv[1]);
//	}else Seed = 36;

    Seed = 10;     // Good ones 4, 10, 12, 14, 48, 49

		/* Seed the random-number generator with current time so that
		* the numbers will be different every time we run.
		*
		* srand( (unsigned)time( NULL ) );
		*/
    
    star->key = (unsigned)time( NULL );
    //star->key = Seed;  //Testing Remove
    srand(star->key);

	//srand((unsigned)Seed);
	//int j = randomDieOpenEnded(0);
    /** Done Initializing **/

    star->createStar();
    star->printStar();

	// Ask The User Which Screen Mode They Prefer
	if (MessageBox(NULL,"Would You Like To Run In Fullscreen Mode?", "Start FullScreen?",MB_YESNO|MB_ICONQUESTION)==IDNO)
	{
		fullscreen=FALSE;						// Windowed Mode
	}

	// Create Our OpenGL Window
	if (!CreateGLWindow("Star System 3D",640,480,16,fullscreen))
	{
		return 0;							// Quit If Window Was Not Created
	}

	while(!done)								// Loop That Runs Until done=TRUE
	{
		if (PeekMessage(&msg,NULL,0,0,PM_REMOVE))			// Is There A Message Waiting?
		{
			if (msg.message==WM_QUIT)				// Have We Received A Quit Message?
			{
				done=TRUE;					// If So done=TRUE
			}
			else							// If Not, Deal With Window Messages
			{
				TranslateMessage(&msg);				// Translate The Message
				DispatchMessage(&msg);				// Dispatch The Message
			}
		}
		else								// If There Are No Messages
		{
			// Draw The Scene.  Watch For ESC Key And Quit Messages From DrawGLScene()
			if (active)						// Program Active?
			{
				if (keys[VK_ESCAPE])				// Was ESC Pressed?
				{
					done=TRUE;				// ESC Signalled A Quit
				}
				else						// Not Time To Quit, Update Screen
				{
					DrawGLScene();				// Draw The Scene
					SwapBuffers(hDC);			// Swap Buffers (Double Buffering)
				}
			}
			if (keys['L'] && !lp)				// L Key Being Pressed Not Held?
			{
				lp=TRUE;				// lp Becomes TRUE
				light=!light;				// Toggle Light TRUE/FALSE
			}
			if (!keys['L'])					// Has L Key Been Released?
			{
				lp=FALSE;				// If So, lp Becomes FALSE
			}
	        if (keys['B'] && !bp)				// Is B Key Pressed And bp FALSE?
	        {
        		bp=TRUE;				// If So, bp Becomes TRUE
        		blend = !blend;				// Toggle blend TRUE / FALSE	
        	}
        	if (!keys['B'])					// Has B Key Been Released?
        	{
        		bp=FALSE;				// If So, bp Becomes FALSE
        	}
	        if (keys['M'] && !mp)				// Is M Key Pressed And bp FALSE?
	        {
        		mp=TRUE;				// If So, bp Becomes TRUE
        		masking = !masking;				// Toggle masking TRUE / FALSE	
        	}
        	if (!keys['M'])					// Has B Key Been Released?
        	{
        		mp=FALSE;				// If So, bp Becomes FALSE
        	}
        	if (keys['F'] && !fp)				// Is F Key Being Pressed?
			{
				fp=TRUE;				// fp Becomes TRUE
				filter+=1;				// filter Value Increases By One
				if (filter>2)				// Is Value Greater Than 2?
				{
					filter=0;			// If So, Set filter To 0
				}
			}
			if (!keys['F'])					// Has F Key Been Released?
			{
				fp=FALSE;				// If So, fp Becomes FALSE
			}
            if (keys['O'] && !op)				// Is O Key Being Pressed?
			{
        		op=TRUE;				    // If So, op Becomes TRUE
        		orbits = !orbits;				// Toggle orbits TRUE / FALSE
			}
			if (!keys['O'])					// Has O Key Been Released?
			{
				op=FALSE;				// If So, op Becomes FALSE
			}
        	if (keys[' '] && !sp)				// Is Space Key Being Pressed?
			{
				sp=TRUE;				// sp Becomes TRUE
                xspeed = 0;
                yspeed = 0;
			}
			if (!keys[' '])					// Has Space Key Been Released?
			{
				sp=FALSE;				// If So, sp Becomes FALSE
			}
			if (keys[VK_PRIOR])				// Is Page Up Being Pressed?
			{
				z-=1.0f;				// If So, Move Into The Screen
			}
			if (keys[VK_NEXT])				// Is Page Down Being Pressed?
			{
				z+=1.0f;				// If So, Move Towards The Viewer
			}
			if (keys[VK_UP])				// Is Up Arrow Being Pressed?
			{
				xspeed-=0.01f;				// If So, Decrease xspeed
			}
			if (keys[VK_DOWN])				// Is Down Arrow Being Pressed?
			{
				xspeed+=0.01f;				// If So, Increase xspeed
			}
			if (keys[VK_RIGHT])				// Is Right Arrow Being Pressed?
			{
				yspeed+=0.01f;				// If So, Increase yspeed
			}
			if (keys[VK_LEFT])				// Is Left Arrow Being Pressed?
			{
				yspeed-=0.01f;				// If So, Decrease yspeed
			}
			if (keys[VK_RETURN])				// Is Enter Being Pressed?
			{
                star->key = (unsigned)time( NULL );  // If So, reset the random seed and redo the star system
                srand(star->key);
                star->createStar();
			}
			if (keys[VK_F1])					// Is F1 Being Pressed?
			{
				keys[VK_F1]=FALSE;				// If So Make Key FALSE
				KillGLWindow();					// Kill Our Current Window
				fullscreen=!fullscreen;				// Toggle Fullscreen / Windowed Mode
				// Recreate Our OpenGL Window
				if (!CreateGLWindow("Star System 3D",640,480,16,fullscreen))
				{
					return 0;				// Quit If Window Was Not Created
				}
			}
			if (keys[VK_HOME])					// Is Down Arrow Being Pressed?
			{
				keys[VK_HOME]=FALSE;				// If So Make Key FALSE
                shown--;
			}
			if (keys[VK_END])					// Is Down Arrow Being Pressed?
			{
				keys[VK_END]=FALSE;				// If So Make Key FALSE
                shown++;
			}
		}
	}



	// Shutdown
	KillGLWindow();								// Kill The Window
	return (msg.wParam);							// Exit The Program
}